******************************************************
** PROJECT : MONSOON ENGINEERING
** TITLE : EXEC PORTION OF TEST ALADDIN CODE MODIFIED TO ACHIEVE SYNCRONIZATION BETWEEN
** : TWO OR MORE DHE MODULES.
** VERSION : 002
** DATE : 08/30/2006
** AUTHOR : PETER MOORE
** HISTORY : 12/09/2003 PCM ORIGINAL VERSION SCULPTED FROM EXEC ON ALADDIN.
** : 08/30/2006 PCM ADOPTED CODE TO REFLECT CCD USE OF ASM4. UPDATED JUMPER
** : DESIGNATIONS FOR MCB REVISION A HARDWARE.
**
** DESCRIPTION :
** : DUMMY SEQUENCER EXEC PORTION TO EXERCISE AND DEMONSTRATE THE SYNC
** : FUNCTIONALITY.
** :
** : NORMAL READOUT CODE IS REPLACED BY A DUMMY STUB THAT JUST RETURNS.
** : FOR ACTUAL USE YOU WOULD INSERT YOUR CODE AT THE STUBS
** :
** : TO USE THIS CODE THE MASTER AND SLAVE DHES NEED TO BE LINKED WITH THE SYNC
** : CABLE. MASTER SYNC OUT => SLAVE SYNC IN. THE SLAVE DHE SHOULD BE SET TO
** : USE THE EXTERNAL CLOCK (JP3 2=>3) AND ADJUSTED IN PHASE (VIA THE MCB_CLKINCTL
** : AND MCB_CLKOUTCTL FUNCTIONS) TO BE COINCIDENT WITH THE MASTER SYSTEM CLOCK.
** : THE SYNC CABLE CONNECTING THE MASTER AND SLAVE DHES MUST HAVE LESS THAN
** : 45ns OF DELAY IN ITS ENTIRE LENGTH (approximately 7 meters physical length).
** :
** : JP2 NEEDS TO BE JUMPERED FOR EXTERNAL SYNC IN THE SLAVE DHE AND REMOVED
** : IN THE MASTER DHE.
** :
** : THE PAN SETS THE MASTER AND SLAVE MODE IN THE RELEVENT DHES VIA
** : THE MCB CONTROL REGISTER BIT 15. BIT SET INDICATES MASTER MODE.
** :
** : THE PAN THEN ISSUES A NORMAL "START EXPOSURE" COMMAND WITH A VECTOR (1 IN THIS
** : EXAMPLE). ALL SEQUENCERS JUMP OUT OF THEIR IDLE MODE AND AWAIT THE ARRIVAL OF SYNC.
** : SYNC IS DELAYED BY A FIRMWARE DELAY GENERATOR BY A VALUE THAT EXCEEDS THE
** : ESTIMATED MAXIMUM LATENCY OF THE START EXPOSURE COMMAND REACHING EACH
** : INDIVIDUAL PAN NODE. THE SYNC IS EMMITED BY THE MASTER TO ALL SLAVES AFTER THE
** : DELAY. THE MASTER RECEIVES ITS OWN SYNC SIGNAL IN THE SAME FASHION (AND AT THE SAME
** : TIME) AS THE SLAVES. WHEN SYNC IS RECEIVED AND RECOGNIZED BY THE SEQUENCER BRANCH
** : INSTRUCTION, ALL SEQUENCERS RUN THE SAME CODE ON THE SAME CLOCK EDGE.
** :
**
** RESOURCES :
**
**************************************************************
** JUMP FLAG DEFINITIONS - BIT POSITION IN COMMAND REGISTER **
**************************************************************
DEF #SYNC 1 * Jump on sync bit high
DEF #ITC 2 * Jump on Integration time expired
DEF #START 3 * Jump on start exposure flag set
DEF #CCDREADOUT 4 * STRVCTR = 1: DO COMPLETE CCD CLEAR - INTEGRATE - READ
DEF #CCDCLEAR 5 * STRVCTR = 2: DO CCD CLEAR ONLY
DEF #CCDREAD 6 * STRVCTR = 4: DO CCD READ ONLY
DEF #VCTR_4 7 * STRVCTR = 8:
DEF #VCTR_5 8 * STRVCTR = 16:
DEF #VCTR_6 9 * STRVCTR = 32:
DEF #VCTR_7 10 * STRVCTR = 64:
DEF #VCTR_8 11 * STRVCTR =128:
DEF #CONT_RUN 12 * USER BIT 1: LOOP INDEFINATELY ON TESTS
DEF #USR_2 13 * Jump on user mode bit value 2
DEF #USR_3 14 * Jump on user mode bit value 4
DEF #CONT_CLR 15 * Jump on user mode bit value 8
**
****************************
** EFR REGISTER CONSTANTS **
****************************
DEF #KILL_EXPFLG x00000001 * Cancel start exposure flag using the EFR register
DEF #STRT_INTCNTR x00000002 * Start the integration time counter using the EFR register
DEF #STOP_INTCNTR x00000004 * Stop the integration time counter using the EFR register
DEF #LSR_AUTO_KILL x00000100 * Enables automatic board select cancel after an LSR instruction
DEF #LSR_MAN_RESET x00000200 * Disables automatic board select cancel. LSR will remain active
*until an LSR #DSLCT is issued
DEF #SET_SYNC_LOW x00004000 * If enabled as master DHE, set sync bit low after sync delay
DEF #SET_SYNC_HIGH x00008000 * If enabled as master DHE, set sync signal high immediately
DEF #KILLANDSYNC x00004001 * Set sync low and kill start exposure flag
**
*****************************
** MODE REGISTER CONSTANTS **
*****************************
DEF #RESET 0 * Mode register constant for board reset operation
DEF #READ 1 * Mode register constant for read operation
DEF #WRITE16 2 * Mode register constant for 16 bit write operation
DEF #WRITE32 3 * Mode register constant for 32 bit write operation
**
**********************************
** LSR BOARD SELECT ASSIGNMENTS **
**********************************
DEF #DSLCT 0
DEF #MCB 1
********************************
** PATTERN MEMORY DEFINITIONS **
********************************
** PATTERN MEMORY SEGMENTATION MAP
DEF #PATSEG_00 x0000 * Pattern memory origin - Initialization stuff
**
** ADDITIONAL DEFINITIONS USUALLY GO HERE
**
**
***************************************
** INSTANTIATE PATTERN MEMORY VALUES **
***************************************
ORG PAT #PATSEG_00 * ********* GENERAL CONSTANTS KEPT IN PAT MEM *********
PAT #KILL_EXPFLG #KILL_EXPFLG * We can use the same label name here because
*they are in different contexts
PAT #STRT_INTCNTR #STRT_INTCNTR * The definition earlier points to a data value. The 
PAT #STOP_INTCNTR #STOP_INTCNTR * label here points to a pattern memory address
PAT #SET_SYNC_LOW #SET_SYNC_LOW * CODE VALUE TO WRITE TO EFR TO SET SYNC PIN LOW
PAT #SET_SYNC_HIGH #SET_SYNC_HIGH * CODE VALUE TO WRITE TO EFR TO SET SYNC PIN HIGH
*************************************
* PROGRAM CODE SEGMENT STARTS HERE **
*************************************
** EXECUTIVE ROUTINE
#INIT CAL #INIT * SET DETECTOR UP FOR INITIAL CONDITIONS
LMR #WRITE32
LPP #SET_SYNC_HIGH
LSR #MCB * SET SYNC BIT HIGH AS INITIAL CONDITION
#EXEC JCB #GOBABY #START * IF START EXPOSURE FLAG SET
JMP #EXEC * ELSE JUMP BACK TO EXEC
#GOBABY LPP #KILL_EXPFLG * KILL THE START EXP FLAG PATTERN = 0x00000001
LSR #MCB * WRITE TO THE EFR
LPP #SET_SYNC_LOW
LSR #MCB * TRIGGER THE SYNC SIGNAL. NOTHING HAPPENS HERE
			* UNTIL THE DELAY HAS EXPIRED.

#WAIT JCB #WAIT #SYNC * SYNC GOES FALSE SYNCHRONOUSLY ON ALL DHES AFTER DELAY
LPP #SET_SYNC_HIGH
LSR #MCB * RESET SYNC BIT HIGH
JCB #JRDOUT #CCDREADOUT * DO CLEAR - INTEGRATE - READOUT OPERATION
JCB #JCLEAR #CCDCLEAR * DO CLEAR ONLY
JCB #JREAD #CCDREAD * DO READ ONLY
JMP #EXEC * NO FLAGS SET, GO HOME.
#JRDOUT CAL #CLEAR
LPP #STRT_INTCNTR
LSR #MCB * START INTEGRATION TIMER RUNNING
NOP * A bug in the MPU .. needs time to reset the flag
NOP
#RD1 JCB #RD2 #ITC * WAIT FOR INTEGRATION TIME
JMP #RD1
#RD2 LPP #STOP_INTCNTR
LSR #MCB * STOP INTEGRATION TIMER
CAL #ARRAY_READ
JCB #JRDOUT #CONT_RUN * DO IT ALL AGAIN IF TOLD TO DO SO
JMP #EXEC * CALL IT A DAY
#JCLEAR CAL #CLEAR
JMP #EXEC
#JREAD CAL #READ
JMP #EXEC