-------------------------------------------------------------------------------
-- Title      : Reset module
-- Project    : 
-------------------------------------------------------------------------------
-- File       : reset.vhd
-- Author     :   <otger@PWOTGER>
-- Company    : 
-- Created    : 2008-12-09
-- Last update: 2009-05-05
-- Platform   : 
-- Standard   : VHDL'87
-------------------------------------------------------------------------------
-- Description: simple reset logic. When a reset is issued from SW (slink) or
-- HW(pushbutton) it sets reset (and reset_n) for 1us. It is intended that this
-- reset is used by all MCB FW.
-------------------------------------------------------------------------------
-- Copyright (c) 2008 
-------------------------------------------------------------------------------
-- Revisions  :
-- Date        Version  Author  Description
-- 2008-12-09  1.0      otger   Created
-------------------------------------------------------------------------------
library ieee;
use ieee.std_logic_1164.all;

entity McbFullReset is
  
  generic (
    pixResetLength : integer := 80000;  -- 40 ticks of sysClk = 1 us
    seqResetLength : integer := 80);      

  port (
    sysClk      : in  std_logic;
    resetInSw_n : in  std_logic;
    resetInHw_n : in  std_logic;
    seqResetOut : out std_logic;
    pixResetOut : out std_logic);

end McbFullReset;

architecture leia of McbFullReset is
  signal resetPix_n : std_logic;
  signal resetSeq_n : std_logic;
begin  -- leia

  resetPix_n <= resetInHw_n and resetInSw_n;
  resetSeq_n <= resetInHw_n;

  seqReset : process (sysClk, resetSeq_n)
    variable resetCounter : integer;
  begin  -- process seqReset
    if resetSeq_n = '0' then            -- asynchronous reset (active low)
      resetCounter := 0;
      seqResetOut  <= '1';
    elsif sysClk'event and sysClk = '1' then  -- rising clock edge
        if resetCounter < seqResetLength then
          seqResetOut <= '1';
        resetCounter := resetCounter + 1;
        else
          seqResetOut <= '0';
        end if;
    end if;
  end process seqReset;


  pixReset : process (sysClk, resetPix_n)
    variable resetCounter : integer;
  begin  -- process pixReset
    if resetPix_n = '0' then            -- asynchronous reset (active low)
      resetCounter := 0;
      pixResetOut  <= '1';
    elsif sysClk'event and sysClk = '1' then  -- rising clock edge
      if resetCounter < pixResetLength then
        pixResetOut  <= '1';
        resetCounter := resetCounter + 1;
      else
        pixResetOut <= '0';
      end if;
    end if;
  end process pixReset;
  

end leia;
