
library ieee;
use ieee.std_logic_1164.all;

package constantsPkg is

  -- Constants
  constant PCB_VERSION : std_logic_vector(15 downto 0) := x"0102";

  -- MASTER CONTROL BOARD PART NUMBER (0400)
  constant BOARDID : std_logic_vector(15 downto 0) := x"0190";
  -- VERSION 5.11
  constant FWVERDEC  : std_logic_vector(15 downto 0) := x"0209";
  constant FWVERHEX  : std_logic_vector(15 downto 0) := x"0521";



  -----------------------------------------------------------------------------
  -- adresses (pixel registers: 0x0200->0x03FF)
  -----------------------------------------------------------------------------
  -- Slink Stats Range (0x0300 -> 0x31f) (Some spares)
  constant ADDR_RANGE_SLINK   : std_logic_vector(15 downto 5) := x"03" & "000";
  -- statsRcvdDatWrd
  constant ADDR_SLINK_SRDW_L  : std_logic_vector(15 downto 0) := x"0300";
  constant ADDR_SLINK_SRDW_H  : std_logic_vector(15 downto 0) := x"0301";
  -- statsRcvdCtlWrd
  constant ADDR_SLINK_SRCW_L  : std_logic_vector(15 downto 0) := x"0302";
  constant ADDR_SLINK_SRCW_H  : std_logic_vector(15 downto 0) := x"0303";
  -- statsXferDatWrd
  constant ADDR_SLINK_SXDW_L  : std_logic_vector(15 downto 0) := x"0304";
  constant ADDR_SLINK_SXDW_H  : std_logic_vector(15 downto 0) := x"0305";
  -- statsXferCtlWrd
  constant ADDR_SLINK_SXCW_L  : std_logic_vector(15 downto 0) := x"0306";
  constant ADDR_SLINK_SXCW_H  : std_logic_vector(15 downto 0) := x"0307";
  -- statsXferDatPag
  constant ADDR_SLINK_SXDP_L  : std_logic_vector(15 downto 0) := x"0308";
  constant ADDR_SLINK_SXDP_H  : std_logic_vector(15 downto 0) := x"0309";
  -- statsXferCtlPag
  constant ADDR_SLINK_SXCP_L  : std_logic_vector(15 downto 0) := x"030a";
  constant ADDR_SLINK_SXCP_H  : std_logic_vector(15 downto 0) := x"030b";
  -- statsXferDatCPag
  constant ADDR_SLINK_SXDCP_L : std_logic_vector(15 downto 0) := x"030c";
  constant ADDR_SLINK_SXDCP_H : std_logic_vector(15 downto 0) := x"030d";
  -- statsXferCtlCPag
  constant ADDR_SLINK_SXCCP_L : std_logic_vector(15 downto 0) := x"030e";
  constant ADDR_SLINK_SXCCP_H : std_logic_vector(15 downto 0) := x"030f";
  -- statsLFFErr 
  constant ADDR_SLINK_SLFFE   : std_logic_vector(15 downto 0) := x"0310";
  -- statsLDownErr
  constant ADDR_SLINK_SLDE    : std_logic_vector(15 downto 0) := x"0311";
  -- statsUpTimeMin
  constant ADDR_SLINK_SUTM    : std_logic_vector(15 downto 0) := x"0312";
  -- statsUpTimeSec
  constant ADDR_SLINK_SUTS    : std_logic_vector(15 downto 0) := x"0313";
  -- infoPageLength
  constant ADDR_SLINK_IPL     : std_logic_vector(15 downto 0) := x"0314";
  -- infoMaxWait
  constant ADDR_SLINK_IMW     : std_logic_vector(15 downto 0) := x"0315";

  -- SerConfigIFC (0x0200->0x027f)
  -- I've deleted serconfigIfc. when I implement it again
  -- but interfacing 1-wire protocol chip I will use it again
  constant ADDR_RANGE_SCONF : std_logic_vector(15 downto 7) := x"02" & '0';
  -- serial eeprom control register
  constant ADDR_SERFETCH    : std_logic_vector(15 downto 0) := x"0280";

  -- ExtDataLatch
  constant ADDR_EXTDATALATCH : std_logic_vector(15 downto 0) := x"0286";

  -- LedLatch
  constant ADDR_LEDLATCH : std_logic_vector(15 downto 0) := x"0282";

  -- pixCmdDec
  constant ADDR_PIXROWREG  : std_logic_vector(15 downto 0) := x"02d0";
  constant ADDR_PIXCOLREG  : std_logic_vector(15 downto 0) := x"02d1";
  constant ADDR_PIXTIMEREG : std_logic_vector(15 downto 0) := x"02d2";
  constant ADDR_PIXCHANREG : std_logic_vector(15 downto 0) := x"02d3";
  constant ADDR_PIXDLYREG  : std_logic_vector(15 downto 0) := x"02d4";
  constant ADDR_PIXCTLREG  : std_logic_vector(15 downto 0) := x"02fc";
  constant ADDR_FWVERHEX   : std_logic_vector(15 downto 0) := x"02ff";

  -- clk phase adjustment / clock delay chip
--  constant ADDR_CLKCTRLDEC : std_logic_vector(15 downto 0) := x"0281";
  constant ADDR_CLKPHASE : std_logic_vector(15 downto 0) := x"0281";

------------------------------------------------------------------------
-- CONSTANTS FOR RESET MODES
------------------------------------------------------------------------
  constant ADDR_RELOADFW : std_logic_vector(15 downto 0) := x"FFFF";  -- BOARD CODE REVISION IDENTITY REGISTER
  constant ADDR_SOFTRESET : std_logic_vector(15 downto 0) := x"FFFE";  -- BOARD FUNCTIONAL IDENTITY REGISTER

  -----------------------------------------------------------------------------
  -- adresses (sequencer registers)
  -----------------------------------------------------------------------------

  constant ADDR_PCB_VERSION  : std_logic_vector(15 downto 0) := x"0600";
  constant ADDR_SYNC_DELAY   : std_logic_vector(15 downto 0) := x"0601";
  constant ADDR_REPROGRAM    : std_logic_vector(15 downto 0) := x"0666";
--  constant ADDR_EVENTREG     : std_logic_vector(15 downto 0) := x"fff0";
  constant ADDR_SWITCHES     : std_logic_vector(15 downto 0) := x"fff8";
  constant ADDR_SEQ_LED      : std_logic_vector(15 downto 0) := x"fff9";
  constant ADDR_BOARDSERIAL  : std_logic_vector(15 downto 0) := x"fffa";
  constant ADDR_BOARDTEMP    : std_logic_vector(15 downto 0) := x"fffb";
  constant ADDR_SEQCTLREG    : std_logic_vector(15 downto 0) := x"fffc";
  constant ADDR_SEQSTATUS    : std_logic_vector(15 downto 0) := x"fffd";
  constant ADDR_BOARDIDREG   : std_logic_vector(15 downto 0) := x"fffe";
  constant ADDR_FWVERDEC     : std_logic_vector(15 downto 0) := x"ffff";
  constant ADDR_SEQINTEGTIME : std_logic_vector(15 downto 0) := x"0000";
  constant ADDR_COUNTREG     : std_logic_vector(15 downto 0) := x"0001";
  constant ADDR_CLOCKEN      : std_logic_vector(15 downto 0) := x"0100";
  constant ADDR_SEQACTINTTIM : std_logic_vector(15 downto 0) := x"0101";
  constant ADDR_SEQCMDREG    : std_logic_vector(15 downto 0) := x"0102";
  constant ADDR_STARTEXP     : std_logic_vector(15 downto 0) := x"0602";
  constant ADDR_SYNCINCNT    : std_logic_vector(15 downto 0) := x"0603";
  constant ADDR_SYNCOUTCNT   : std_logic_vector(15 downto 0) := x"0604";


  -----------------------------------------------------------------------------
  -- Sequencer adresses ranges
  -----------------------------------------------------------------------------
  -- Sequencer loop range 0x0110 -> 0x011f
  constant ADDR_RANGE_SEQLOOP   : std_logic_vector(15 downto 4)  := x"011";
  -- Sequencer pattern memory range (0x1000->0x1bff) can not be described this
  -- way. It is hardcoded on Personality module.
  constant ADDR_RANGE_SEQPATMEM : std_logic_vector(15 downto 12) := x"1";
  -- sequencer programm memory 0x4000 -> 0x43ff
  constant ADDR_RANGE_SEQPRGMEM : std_logic_vector(15 downto 10) := x"4"&"00";
  -- pixel command range 0x0200 -> 0x03ff
  constant ADDR_RANGE_PIXCMD    : std_logic_vector(15 downto 9)  := x"0" & "001";
  

end constantsPkg;
