-------------------------------------------------------------------------------
-- Title      : MCBFull
-- Project    : 
-------------------------------------------------------------------------------
-- File       : mcbFull.vhd
-- Author     :   <otger@WWOTGER>
-- Company    : 
-- Created    : 2008-01-23
-- Last update: 2010-12-15
-- Platform   : 
-- Standard   : VHDL'87
-------------------------------------------------------------------------------
-- Description: Top of new MCB fpga
-------------------------------------------------------------------------------
-- Copyright (c) 2008 
-------------------------------------------------------------------------------
-- Revisions  :
-- Date        Version  Author  Description
-- 2008-01-23  1.0      otger   Created
-- 2008-12-08           otger   Changed pin reset_n by resetIn_n
--                              Added reset module
--                              Removed rst_n pin
-------------------------------------------------------------------------------


library ieee;
use ieee.std_logic_1164.all;
use ieee.std_logic_unsigned.all;
-- synopsys translate_off
library UNISIM;
use UNISIM.Vcomponents.all;
-- synopsys translate_on

entity mcbFull is
  
  port (
    sysclk    : in    std_logic;
    dq        : inout std_logic;
    temp_sclk : out   std_logic;
    temp_dout : in    std_logic;
    temp_din  : out   std_logic;

    program_n  : out std_logic;
    testPoints : out std_logic_vector(7 downto 0);

    bp_boardSel_n : out std_logic_vector(8 downto 2);
    bp_seqMode    : out std_logic_vector(1 downto 0);
    dev_addr      : out std_logic_vector(5 downto 0);
    seq_data      : out std_logic_vector(31 downto 0);
    bp_clk        : out std_logic_vector(8 downto 2);
    sync_in       : in  std_logic;
    sync_out      : out std_logic;
    start_exp     : out std_logic;
    pix_data      : in  std_logic_vector(47 downto 0);
    pipe_req_n    : in  std_logic_vector(6 downto 0);
    pipe_wrt_n    : in  std_logic;

    exdat_in      : in  std_logic;
    exdat_out     : out std_logic;
    -- Leds
    led_master    : out std_logic;
    led_seq       : out std_logic;
    led_link_up   : out std_logic;
    led_activity  : out std_logic;
    led_fifofull  : out std_logic;
    -- Clock Selector (local or Extern clock)
    clkSwitchSel  : out std_logic;
    -- Sync signal selector (local or Extern)
    syncSwitchSel : out std_logic;
    -- Slink signals
    sl_uclk       : out std_logic;
    sl_uctrl_n    : out std_logic;
    sl_ud         : out std_logic_vector(31 downto 0);
    sl_lrl        : in  std_logic_vector(3 downto 0);
    sl_lff_n      : in  std_logic;
    sl_utest_n    : out std_logic;
    sl_ldown_n    : in  std_logic;
    sl_uwen_n     : out std_logic;
    sl_ureset_n   : out std_logic;
    sl_ra_err_n   : out std_logic;

    -- delay chips signals
    delChipClk      : out std_logic;
    delChipD        : out std_logic;
    syncDelayChipEn : out std_logic;
    clkDelayChipEn  : out std_logic;

--    bp_ack_n : in std_logic_vector(8 downto 2);

    resetInHw : in std_logic;           -- board reset

    bp_spare : in std_logic_vector(8 downto 0);

    temp_cs : out std_logic
    );
end mcbFull;

architecture behavioral of mcbFull is

  -----------------------------------------------------------------------------
  -- Components
  -----------------------------------------------------------------------------
  -- Reset
  component McbFullReset
    generic (
      pixResetLength : integer;
      seqResetLength : integer);
    port (
      sysClk      : in  std_logic;
      resetInSw_n : in  std_logic;
      resetInHw_n : in  std_logic;
      seqResetOut : out std_logic;
      pixResetOut : out std_logic);
  end component;

  -- Top pix
  component topPixFpga
    port (
      reset           : in  std_logic;
      dataRdy         : out std_logic;
      dataOut         : out std_logic_vector(31 downto 0);
      dataRead        : in  std_logic;
      dataIn          : in  std_logic_vector(31 downto 0);
      cmdRdy          : in  std_logic;
      seqDataReq      : in  std_logic;
      pixSeqSyncIn    : in  std_logic;
      simTrigger      : in  std_logic;
      pix_data        : in  std_logic_vector(47 downto 0);
      pipe_req_n      : in  std_logic_vector(6 downto 0);
      pipe_wrt_n      : in  std_logic;
      seqWrite_n      : in  std_logic;
      sysclk          : in  std_logic;
      activityLed     : out std_logic;
      xoffLed         : out std_logic;
      linkUpLed       : out std_logic;
      exdat_in        : in  std_logic;
      exdat_out       : out std_logic;
      uclk            : out std_logic;
      ud              : out std_logic_vector(31 downto 0);
      lrl             : in  std_logic_vector(3 downto 0);
      lff_n           : in  std_logic;
      utest_n         : out std_logic;
      ldown_n         : in  std_logic;
      uwen_n          : out std_logic;
      uctrl_n         : out std_logic;
      slinkResetOut_n : out std_logic;
      ureset_n        : out std_logic);
  end component;


  -- Former Sequencer Fpga  Top
  component topSeqFpga
    port (
      reset      : in    std_logic;
      SYNC_IN    : in    std_logic;
      SYSCLK     : in    std_logic;
      TEMP_DOUT  : in    std_logic;
      BRD_SLCT_N : out   std_logic_vector (8 downto 2);
      bp_clk     : out   std_logic_vector(8 downto 2);
      DEV_ADDR   : out   std_logic_vector (4 downto 0);
      seqWrite_n : out   std_logic;
      simTrigger : out   std_logic;
      PROGRAM_N  : out   std_logic;
      RA_LINK_N  : out   std_logic;
      SEQ_DATA   : out   std_logic_vector (31 downto 0);
      SEQ_MODE   : out   std_logic_vector (1 downto 0);
      START_EXP  : out   std_logic;
      SYNC_OUT   : out   std_logic;
      TEMP_DIN   : out   std_logic;
      TEMP_SCLK  : out   std_logic;
      TEMP_CS    : out   std_logic;
      DQ         : inout std_logic;

      clkSwitchSel  : out std_logic;
      syncSwitchSel : out std_logic;

      led_isMaster : out std_logic;
      led_seqRunning    : out   std_logic;

      delChipClk      : out std_logic;
      delChipD        : out std_logic;
      syncDelayChipEn : out std_logic;
      clkDelayChipEn  : out std_logic;
      dataRdy         : in  std_logic;
      dataIn          : in  std_logic_vector(31 downto 0);
      dataRead        : out std_logic;
      dataOut         : out std_logic_vector(31 downto 0);
      cmdRdy          : out std_logic;
      seqDataReq      : out std_logic;
      pixSeqSyncOut   : out std_logic);
  end component;

  -----------------------------------------------------------------------------
  -- Signals
  -----------------------------------------------------------------------------
  signal seqWrite_n : std_logic;

  signal simTrigger : std_logic;

  signal fpgaDataRdy    : std_logic;
  signal fpgaDataP2S    : std_logic_vector(31 downto 0);
  signal fpgaDataRead   : std_logic;
  signal fpgaDataS2P    : std_logic_vector(31 downto 0);
  signal fpgaCmdRdy     : std_logic;
  signal fpgaSeqDataReq : std_logic;
  signal fpgaSyncS2P    : std_logic;

  signal sysclk_int : std_logic;

  signal resetSw_n : std_logic;

  signal seqResetOut : std_logic;
  signal pixResetOut : std_logic;
  signal resetInHw_n : std_logic;


  signal sync_out_tmp : std_logic;
--  signal syncOut_tmp2 : std_logic;

--  signal intLedFib : std_logic;

begin  -- behavioral


--  led_master <= intLedFib;
  --led_activity <= intLedFib;
  --led_link_up  <= sl_ldown_n;
  --led_fifofull <= isMaster;

  ---- To debug sync paths I change from sync_out_tmp to a slow clock
  --process (sysclk, seqResetOut)
  --  variable ix : integer range 0 to 15 := 15;
  --begin  -- process
  --  if seqResetOut = '1' then             -- asynchronous reset (active high)
  --    syncOut_tmp2 <= '0';
  --    ix := 15;
  --  elsif sysclk'event and sysclk = '1' then  -- rising clock edge
  --    if ix = 0 then
  --      syncOut_tmp2 <= not syncOut_tmp2;
  --      ix := 15;
  --    else
  --      ix := ix - 1;
  --    end if;
  --  end if;
  --end process;
  --sync_out <= syncOut_tmp2;
  sync_out <= not sync_out_tmp;

  dev_addr(5) <= '0';



  topSeqFpga_1 : topSeqFpga
    port map (
      SYSCLK     => sysclk_int,            --
      reset      => seqResetOut,
      SYNC_IN    => sync_in,               --
      TEMP_DOUT  => temp_dout,             --
      BRD_SLCT_N => bp_boardSel_n,         --
      bp_clk     => bp_clk,
      DEV_ADDR   => dev_addr(4 downto 0),  --
      seqWrite_n => seqWrite_n,            --
      simTrigger => simTrigger,            --
      PROGRAM_N  => program_n,             --
      RA_LINK_N  => sl_ra_err_n,           --
      SEQ_DATA   => seq_data,              --
      SEQ_MODE   => bp_seqMode,            --
      START_EXP  => start_exp,             --
      SYNC_OUT   => sync_out_tmp,          --
      TEMP_DIN   => temp_din,              --
      TEMP_SCLK  => temp_sclk,             --
      TEMP_CS    => temp_cs,


      DQ            => dq,              --

      led_seqRunning    => led_seq,               --
      led_isMaster      => led_master,

      clkSwitchSel  => clkSwitchSel,
      syncSwitchSel => syncSwitchSel,

      delChipClk      => delChipClk,
      delChipD        => delChipD,
      syncDelayChipEn => syncDelayChipEn,
      clkDelayChipEn  => clkDelayChipEn,

      dataRdy    => fpgaDataRdy,
      dataOut    => fpgaDataS2P,
      dataRead   => fpgaDataRead,
      dataIn     => fpgaDataP2S,
      cmdRdy     => fpgaCmdRdy,
      seqDataReq => fpgaSeqDataReq,
      pixSeqSyncOut    => fpgaSyncS2P
      );                                --




  -----------------------------------------------------------------------------
  -- Top pix fpga
  -----------------------------------------------------------------------------
  topPixFpga_1 : topPixFpga
    port map (
      reset           => pixResetOut,
      dataRdy         => fpgaDataRdy,
      dataOut         => fpgaDataP2S,
      dataRead        => fpgaDataRead,
      dataIn          => fpgaDataS2P,
      cmdRdy          => fpgaCmdRdy,
      seqDataReq      => fpgaSeqDataReq,
      pixSeqSyncIn    => fpgaSyncS2P,
      simTrigger      => simTrigger,    --
      pix_data        => pix_data,      --
      pipe_req_n      => pipe_req_n,    --
      pipe_wrt_n      => pipe_wrt_n,    --
      seqWrite_n      => seqWrite_n,    --
      sysclk          => sysclk_int,    --
      exdat_in        => exdat_in,      --
      exdat_out       => exdat_out,     --
      uclk            => sl_uclk,       --
      ud              => sl_ud,         --
      lrl             => sl_lrl,        --
      lff_n           => sl_lff_n,      --
      utest_n         => sl_utest_n,    --
      ldown_n         => sl_ldown_n,    --
      uwen_n          => sl_uwen_n,     --
      uctrl_n         => sl_uctrl_n,    --
      slinkResetOut_n => resetSw_n,
      ureset_n        => sl_ureset_n,
      activityLed     => led_activity,
      xoffLed         => led_fifofull,
      linkUpLed       => led_link_up);  --


  sysclk_int <= sysclk;


  -----------------------------------------------------------------------------
  -- Test points
  -----------------------------------------------------------------------------

  testPoints <= (others => '0');


  -----------------------------------------------------------------------------
  -- Reset module
  -- It accepts resets from SW and HW and generates a reset for all the MCB FW
  -- that lasts 1us (if resetLength = 40)
  -----------------------------------------------------------------------------

  resetInHw_n <= not resetInHw;

  reset_1 : McbFullReset
    generic map (
      pixResetLength => 80,
      seqResetLength => 80)
    port map (
      sysClk      => sysClk,
      resetInSw_n => resetSw_n,
      resetInHw_n => resetInHw_n,
      seqResetOut => seqResetOut,
      pixResetOut => pixResetOut);

end behavioral;
