-------------------------------------------------------------------------------
-- Title      : PackagePixel
-- Project    : 
-------------------------------------------------------------------------------
-- File       : PackagePixel.vhd
-- Author     :   <otger@WWOTGER>
-- Company    : 
-- Created    : 2008-01-16
-- Last update: 2010-12-14
-- Platform   : 
-- Standard   : VHDL'87
-------------------------------------------------------------------------------
-- Description: Package for all former Pixel FPGA components
-------------------------------------------------------------------------------
-- Copyright (c) 2008 
-------------------------------------------------------------------------------
-- Revisions  :
-- Date        Version  Author  Description
-- 2008-01-16  1.0      otger   Created
-------------------------------------------------------------------------------

library ieee;
use ieee.std_logic_1164.all;
use ieee.std_logic_arith.all;
use ieee.std_logic_unsigned.all;


-------------------------------------------------------------------------------

package PackagePixel is

  component PIXEL_DATA_FIFO_V461
    port (
      CLK            : in  std_logic;
      RST            : in  std_logic;
      DATA_IN        : in  std_logic_vector(47 downto 0);
      DATA_OUT       : out std_logic_vector(31 downto 0);
      SEQ_WRT_N      : in  std_logic;
      PIPELINE_REQ_N : in  std_logic_vector(6 downto 0);
      PIPELINE_WRT_N : in  std_logic;
      RD             : in  std_logic;
      DBL_WD_XFER    : in  std_logic;
      PIPELINE_ENBL  : in  std_logic;
      DATA_RDY       : out std_logic;
      SYNC_OUT       : out std_logic;
      SIM_ENABLE     : in  std_logic;
      SIM_PIXROWS    : in  std_logic_vector(15 downto 0);
      SIM_PIXCOLS    : in  std_logic_vector(15 downto 0);
      SIM_PIXTIME    : in  std_logic_vector(7 downto 0);
      SIM_CHANNELS   : in  std_logic_vector(6 downto 0);
      SIM_DELAY      : in  std_logic_vector(7 downto 0);
      SIM_TRIGGER    : in  std_logic);
  end component;

  component PixCmdDecodeV461
    port (
      SYSCLK       : in    std_logic;
      RESET        : in    std_logic;
      CMD_RDY      : in    std_logic;
--      CMD_ACK      : out   std_logic;
      CMD_READ     : in    std_logic;
      CMD_DATA     : in    std_logic_vector(31 downto 0);
      ADDRESS      : out   std_logic_vector(15 downto 0);
      REG_DATA     : inout std_logic_vector(15 downto 0);
      DATA_OUT     : out   std_logic_vector(15 downto 0);
      READ_REQ     : out   std_logic;
      READ_ACK     : in    std_logic;
      READ_SYNC    : out   std_logic;
      READ_WRITE_N : out   std_logic;
      EXD_CMD_STB  : out   std_logic;
      SLINK_CMD_STB : out std_logic;
--      CFG_CMD_STB  : out   std_logic;
--      ADC_CMD_STB  : out   std_logic;
--      MOD_CMD_STB  : out   std_logic;
--      DAC_CMD_STB  : out   std_logic;
--      SYN_CMD_STB  : out   std_logic;
--      CLK_CMD_STB  : out   std_logic;
--      FCH_CMD_STB  : out   std_logic;
      LED_CMD_STB  : out   std_logic;
      DBL_WRD_XFER : out   std_logic;
      SIM_ENABLE   : out   std_logic;
      SIM_PIXROWS  : out   std_logic_vector(15 downto 0);
      SIM_PIXCOLS  : out   std_logic_vector(15 downto 0);
      SIM_PIXTIME  : out   std_logic_vector(7 downto 0);
      SIM_CHANNELS : out   std_logic_vector(6 downto 0);
      SIM_DELAY    : out   std_logic_vector(7 downto 0));
  end component;
  
  component regMux
    port (
      address            : in  std_logic_vector(15 downto 0);
      statsRcvdDatWrd    : in  std_logic_vector(31 downto 0);
      statsRcvdCtlWrd    : in  std_logic_vector(31 downto 0);
      statsXferDatWrd    : in  std_logic_vector(31 downto 0);
      statsXferCtlWrd    : in  std_logic_vector(31 downto 0);
      statsXferDatPag    : in  std_logic_vector(31 downto 0);
      statsXferCtlPag    : in  std_logic_vector(31 downto 0);
      statsXferDatCPag   : in  std_logic_vector(31 downto 0);
      statsXferCtlCPag   : in  std_logic_vector(31 downto 0);
      statsLFFErr        : in  std_logic_vector(15 downto 0);
      statsLDownErr      : in  std_logic_vector(15 downto 0);
      statsUpTimeMin     : in  std_logic_vector(15 downto 0);
      statsUpTimeSec     : in  std_logic_vector(5 downto 0);
      infoPageLength     : in  std_logic_vector(15 downto 0);
      infoMaxWait        : in  std_logic_vector(15 downto 0);
      serConfigIfcDatOut : in  std_logic_vector(15 downto 0);
      exDatLatchDatOut   : in  std_logic_vector(15 downto 0);
      ledLatchDatOut     : in  std_logic_vector(15 downto 0);
      pixCmdDecRegData   : in  std_logic_vector(15 downto 0);
--      clkCntrlDecDatOut  : in  std_logic_vector(15 downto 0);
      dataOut            : out std_logic_vector(15 downto 0));
  end component;
  
  component PixDataMuxV40
    port (
      PIX_DATA_IN   : in  std_logic_vector(31 downto 0);
      PIX_DATA_REQ  : in  std_logic;
      PIX_DATA_ACK  : out std_logic;
      PIX_DATA_SYNC : in  std_logic;
      SEQ_DATA_IN   : in  std_logic_vector(31 downto 0);
      SEQ_DATA_REQ  : in  std_logic;
--      SEQ_DATA_ACK  : out std_logic;
      SEQ_DATA_SYNC : in  std_logic;
      LOC_DATA_IN   : in  std_logic_vector(15 downto 0);
      LOC_DATA_REQ  : in  std_logic;
      LOC_DATA_ACK  : out std_logic;
      LOC_DATA_SYNC : in  std_logic;
      DATA_OUT      : out std_logic_vector(31 downto 0);
      DATA_WR       : out std_logic;
      DATA_SYNC     : out std_logic;
      DATA_BUSY     : in  std_logic);
  end component;

  component SLinkIfc
    port (
      SYSCLK           : in  std_logic;
      RESET_IN         : in  std_logic;
      DATA_IN          : in  std_logic_vector (31 downto 0);
      DATA_READ        : in  std_logic;
      DATA_WRT         : in  std_logic;
      DATATYPE         : in  std_logic;
      LDOWN_N          : in  std_logic;
      LFF_N            : in  std_logic;
      LRL              : in  std_logic_vector (3 downto 0);
      clearStats       : in  std_logic;
      statsRcvdDatWrd  : out std_logic_vector(31 downto 0);
      statsRcvdCtlWrd  : out std_logic_vector(31 downto 0);
      statsXferDatWrd  : out std_logic_vector(31 downto 0);
      statsXferCtlWrd  : out std_logic_vector(31 downto 0);
      statsXferDatPag  : out std_logic_vector(31 downto 0);
      statsXferCtlPag  : out std_logic_vector(31 downto 0);
      statsXferDatCPag : out std_logic_vector(31 downto 0);
      statsXferCtlCPag : out std_logic_vector(31 downto 0);
      statsLFFErr      : out std_logic_vector(15 downto 0);
      statsLDownErr    : out std_logic_vector(15 downto 0);
      statsUpTimeMin   : out std_logic_vector(15 downto 0);
      statsUpTimeSec   : out std_logic_vector(5 downto 0);
      infoPageLength   : out std_logic_vector(15 downto 0);
      infoMaxWait      : out std_logic_vector(15 downto 0);
      DATA_BUSY        : out std_logic;
      DATA_OUT         : out std_logic_vector (31 downto 0);
      DATA_RDY         : out std_logic;
      RESET_OUT        : out std_logic;
      UCLK             : out std_logic;
      UCTRL_N          : out std_logic;
      UD               : out std_logic_vector (31 downto 0);
      UTEST_N          : out std_logic;
      URESET_N         : out std_logic;
      UWEN_N           : out std_logic;
      activityLed      : out std_logic;
      linkUpLed        : out std_logic;
      xoffLed          : out std_logic);
  end component;
  
  component ExDataLatchV40
    port (
      SYSCLK    : in    std_logic;
      EXDAT_CS  : in    std_logic;
      READ      : in    std_logic;
      DATA_IN   : in    std_logic;
      DATA_OUT  : out   std_logic_vector(15 downto 0);
      EXDAT_OUT : out   std_logic;
      EXDAT_IN  : in    std_logic);
  end component;

  component SerConfigIfcV42
    port (
      SYSCLK    : in    std_logic;
      RESET     : in    std_logic;
      READ      : in    std_logic;
      FETCH_CS  : in    std_logic;
      SRCFG_CS  : in    std_logic;
      WRITE_EN  : in    std_logic;
      DATA_IN   : in    std_logic_vector(15 downto 0);
      DATA_OUT  : inout std_logic_vector(15 downto 0);
      DATA_ADDR : in    std_logic_vector(6 downto 0);
      SCL       : out   std_logic;
      SDA_IN    : in    std_logic;
      SDA_OUT   : out   std_logic;
      SDA_ENAB  : out   std_logic;
      PING      : out   std_logic;
      PONG      : out   std_logic);
  end component;


  component LedCtrlSlink
    port (
      sysClk         : in  std_logic;
      reset          : in  std_logic;
      sel            : in  std_logic;
      rdWr_n         : in  std_logic;
      dataIn         : in  std_logic_vector(2 downto 0);
      dataOut        : out std_logic_vector(15 downto 0);
      activityLedSrc : in  std_logic;
      linkUpLedSrc   : in  std_logic;
      xoffLedSrc     : in  std_logic;
      activityLed    : out std_logic;
      linkUpLed      : out std_logic;
      xoffLed        : out std_logic);
  end component;
  
end PackagePixel;
