-------------------------------------------------------------------------------
-- Title      : Register Mux selector
-- Project    : 
-------------------------------------------------------------------------------
-- File       : regMux.vhd
-- Author     :   <otger@PWOTGER>
-- Company    : 
-- Created    : 2009-07-01
-- Last update: 2009-12-02
-- Platform   : 
-- Standard   : VHDL'87
-------------------------------------------------------------------------------
-- Description: 
-------------------------------------------------------------------------------
-- Copyright (c) 2009 
-------------------------------------------------------------------------------
-- Revisions  :
-- Date        Version  Author  Description
-- 2009-07-01  1.0      otger   Created
-------------------------------------------------------------------------------

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
use work.constantsPkg.all;

entity regMux is
  
  port (
    address : in std_logic_vector(15 downto 0);  -- address from pixCmdDec

    -- slink registers
    statsRcvdDatWrd  : in std_logic_vector(31 downto 0);
    statsRcvdCtlWrd  : in std_logic_vector(31 downto 0);
    statsXferDatWrd  : in std_logic_vector(31 downto 0);
    statsXferCtlWrd  : in std_logic_vector(31 downto 0);
    statsXferDatPag  : in std_logic_vector(31 downto 0);  -- pages (complete
                                                          -- and incomplete)
    statsXferCtlPag  : in std_logic_vector(31 downto 0);
    statsXferDatCPag : in std_logic_vector(31 downto 0);  -- complete pages
    statsXferCtlCPag : in std_logic_vector(31 downto 0);
    statsLFFErr      : in std_logic_vector(15 downto 0);
    statsLDownErr    : in std_logic_vector(15 downto 0);
    statsUpTimeMin   : in std_logic_vector(15 downto 0);
    statsUpTimeSec   : in std_logic_vector(5 downto 0);
    infoPageLength   : in std_logic_vector(15 downto 0);
    infoMaxWait      : in std_logic_vector(15 downto 0);

    -- SerConfigIFC
    serConfigIfcDatOut : in std_logic_vector(15 downto 0);

    -- ExtDataLatch
    exDatLatchDatOut : in std_logic_vector(15 downto 0);

    -- LedLatch
    ledLatchDatOut : in std_logic_vector(15 downto 0);

    -- pixCmdDec
    pixCmdDecRegData : in std_logic_vector(15 downto 0);

    -- clkCntrlDec
--    clkCntrlDecDatOut : in std_logic_vector(15 downto 0);

    -- input mux
    dataOut : out std_logic_vector(15 downto 0));

end regMux;

architecture behavioral of regMux is

  

begin  -- behavioral

  muxproc : process (address, exDatLatchDatOut, infoMaxWait, infoPageLength,
                     ledLatchDatOut, pixCmdDecRegData, serConfigIfcDatOut,
                     statsLDownErr, statsLFFErr, statsRcvdCtlWrd,
                     statsRcvdDatWrd, statsUpTimeMin, statsUpTimeSec,
                     statsXferCtlCPag, statsXferCtlPag, statsXferCtlWrd,
                     statsXferDatCPag, statsXferDatPag, statsXferDatWrd)
  begin  -- process muxproc
    -- serial interface address range
    if address(15 downto 7) = ADDR_RANGE_SCONF or address = ADDR_SERFETCH then
      dataOut <= serConfigIfcDatOut;
    else
      case address is
        -- slink registers
        when ADDR_SLINK_SRDW_L  => dataOut <= statsRcvdDatWrd(15 downto 0);
        when ADDR_SLINK_SRDW_H  => dataOut <= statsRcvdDatWrd(31 downto 16);
        when ADDR_SLINK_SRCW_L  => dataOut <= statsRcvdCtlWrd(15 downto 0);
        when ADDR_SLINK_SRCW_H  => dataOut <= statsRcvdCtlWrd(31 downto 16);
        when ADDR_SLINK_SXDW_L  => dataOut <= statsXferDatWrd(15 downto 0);
        when ADDR_SLINK_SXDW_H  => dataOut <= statsXferDatWrd(31 downto 16);
        when ADDR_SLINK_SXCW_L  => dataOut <= statsXferCtlWrd(15 downto 0);
        when ADDR_SLINK_SXCW_H  => dataOut <= statsXferCtlWrd(31 downto 16);
        when ADDR_SLINK_SXDP_L  => dataOut <= statsXferDatPag(15 downto 0);
        when ADDR_SLINK_SXDP_H  => dataOut <= statsXferDatPag(31 downto 16);
        when ADDR_SLINK_SXCP_L  => dataOut <= statsXferCtlPag(15 downto 0);
        when ADDR_SLINK_SXCP_H  => dataOut <= statsXferCtlPag(31 downto 16);
        when ADDR_SLINK_SXDCP_L => dataOut <= statsXferDatCPag(15 downto 0);
        when ADDR_SLINK_SXDCP_H => dataOut <= statsXferDatCPag(31 downto 16);
        when ADDR_SLINK_SXCCP_L => dataOut <= statsXferCtlCPag(15 downto 0);
        when ADDR_SLINK_SXCCP_H => dataOut <= statsXferCtlCPag(31 downto 16);
        when ADDR_SLINK_SLFFE   => dataOut <= statsLFFErr(15 downto 0);
        when ADDR_SLINK_SLDE    => dataOut <= statsLDownErr(15 downto 0);
        when ADDR_SLINK_SUTM    => dataOut <= statsUpTimeMin(15 downto 0);
        when ADDR_SLINK_SUTS    => dataOut <= x"00"& "00" & statsUpTimeSec;
        when ADDR_SLINK_IPL     => dataOut <= infoPageLength;
        when ADDR_SLINK_IMW     => dataOut <= infoMaxWait;
        -- extdatalatch
        when ADDR_EXTDATALATCH => dataOut <= exDatLatchDatOut;
        -- LedLatch
        when ADDR_LEDLATCH => dataOut <= ledLatchDatOut;
        -- Pix Command Decode internal registers
        when ADDR_PIXROWREG => dataOut <= pixCmdDecRegData;
        when ADDR_PIXCOLREG => dataOut <= pixCmdDecRegData;
        when ADDR_PIXTIMEREG => dataOut <= pixCmdDecRegData;
        when ADDR_PIXCHANREG => dataOut <= pixCmdDecRegData;
        when ADDR_PIXDLYREG => dataOut <= pixCmdDecRegData;
        when ADDR_PIXCTLREG => dataOut <= pixCmdDecRegData;
        when ADDR_FWVERHEX  => dataOut <= pixCmdDecRegData;
        -- Clock Control Decode
--        when ADDR_CLKCTRLDEC => dataOut <= clkCntrlDecDatOut;
                               

        when others => dataOut <= x"DEFA";
      end case;
    end if;
  end process muxproc;
  
  

end behavioral;

