-------------------------------------------------------------------------------
-- Title      : top of former Pixel FPGA
-- Project    : 
-------------------------------------------------------------------------------
-- File       : topPixFpga.vhd
-- Author     :   <otger@ifae.es>
-- Company    : 
-- Created    : 2008-01-16
-- Last update: 2010-12-15
-- Platform   : 
-- Standard   : VHDL'87
-------------------------------------------------------------------------------
-- Description: 
-------------------------------------------------------------------------------
-- Copyright (c) 2008 
-------------------------------------------------------------------------------
-- Revisions  :
-- Date        Version  Author  Description
-- 2008-01-16  1.0      otger   Created
-------------------------------------------------------------------------------

library ieee;
use ieee.std_logic_1164.all;
use ieee.std_logic_arith.all;
use ieee.std_logic_unsigned.all;
use work.PackagePixel.all;

-- synopsys translate_off
library UNISIM;
use UNISIM.Vcomponents.all;
-- synopsys translate_on

entity topPixFpga is
  
  port (
    reset      : in  std_logic;
    -- FPGA interface
    dataRdy    : out std_logic;
    dataOut    : out std_logic_vector(31 downto 0);
    dataRead   : in  std_logic;
    dataIn     : in  std_logic_vector(31 downto 0);
    cmdRdy     : in  std_logic;
    seqDataReq : in  std_logic;
    pixSeqSyncIn: in  std_logic;

    -- Pixel data fifo
    simTrigger      : in  std_logic;
    pix_data        : in  std_logic_vector(47 downto 0);
    pipe_req_n      : in  std_logic_vector(6 downto 0);
    pipe_wrt_n      : in  std_logic;
    seqWrite_n      : in  std_logic;
    -- global clock
    sysclk          : in  std_logic;
    -- leds
    activityLed     : out std_logic;
    xoffLed         : out std_logic;
    linkUpLed       : out std_logic;
    -- ex data latch
    exdat_in        : in  std_logic;
    exdat_out       : out std_logic;
    -- SLink
    uclk            : out std_logic;
    ud              : out std_logic_vector(31 downto 0);
    lrl             : in  std_logic_vector(3 downto 0);
    lff_n           : in  std_logic;
    utest_n         : out std_logic;
    ldown_n         : in  std_logic;
    uwen_n          : out std_logic;
    uctrl_n         : out std_logic;
    slinkResetOut_n : out std_logic;
    ureset_n        : out std_logic);

end topPixFpga;


architecture Behavioral of topPixFpga is
  ----------------------------------------------------------------------------
  -- Signals
  ----------------------------------------------------------------------------

  signal READWRITE_N : std_logic;

  signal slinkIfc_cs : std_logic;

  signal PIX_DAT_FIFO_DATA_IN        : std_logic_vector(47 downto 0);
  signal PIX_DAT_FIFO_DATA_OUT       : std_logic_vector(31 downto 0);
  signal PIX_DAT_FIFO_SEQ_WRT_N      : std_logic;
  signal PIX_DAT_FIFO_PIPELINE_REQ_N : std_logic_vector(6 downto 0);
  signal PIX_DAT_FIFO_PIPELINE_WRT_N : std_logic;
  signal PIX_DAT_FIFO_RD             : std_logic;
  signal PIX_DAT_FIFO_DBL_WD_XFER    : std_logic;
  signal PIX_DAT_FIFO_PIPELINE_ENBL  : std_logic;
  signal PIX_DAT_FIFO_DATA_RDY       : std_logic;
  signal PIX_DAT_FIFO_SYNC_OUT       : std_logic;
  signal PIX_DAT_FIFO_SIM_ENABLE     : std_logic;
  signal PIX_DAT_FIFO_SIM_PIXROWS    : std_logic_vector(15 downto 0);
  signal PIX_DAT_FIFO_SIM_PIXCOLS    : std_logic_vector(15 downto 0);
  signal PIX_DAT_FIFO_SIM_PIXTIME    : std_logic_vector(7 downto 0);
  signal PIX_DAT_FIFO_SIM_CHANNELS   : std_logic_vector(6 downto 0);
  signal PIX_DAT_FIFO_SIM_DELAY      : std_logic_vector(7 downto 0);
  signal PIX_DAT_FIFO_SIM_TRIGGER    : std_logic;

  signal PIX_CMD_DEC_CMD_RDY      : std_logic;
  signal PIX_CMD_DEC_CMD_READ     : std_logic;
  signal PIX_CMD_DEC_CMD_DATA     : std_logic_vector(31 downto 0);
  signal PIX_CMD_DEC_ADDRESS      : std_logic_vector(15 downto 0);
  signal PIX_CMD_DEC_DATA_OUT     : std_logic_vector(15 downto 0);
  signal PIX_CMD_DEC_READ_REQ     : std_logic;
  signal PIX_CMD_DEC_READ_ACK     : std_logic;
  signal PIX_CMD_DEC_READ_SYNC    : std_logic;
  signal PIX_CMD_DEC_LED_CMD_STB  : std_logic;
  signal PIX_CMD_DEC_EXD_CMD_STB  : std_logic;
  signal PIX_CMD_DEC_DBL_WRD_XFER : std_logic;
  signal PIX_CMD_DEC_SIM_ENABLE   : std_logic;
  signal PIX_CMD_DEC_SIM_PIXROWS  : std_logic_vector(15 downto 0);
  signal PIX_CMD_DEC_SIM_PIXCOLS  : std_logic_vector(15 downto 0);
  signal PIX_CMD_DEC_SIM_PIXTIME  : std_logic_vector(7 downto 0);
  signal PIX_CMD_DEC_SIM_CHANNELS : std_logic_vector(6 downto 0);
  signal PIX_CMD_DEC_SIM_DELAY    : std_logic_vector(7 downto 0);

  signal PIX_DAT_MUX_PIX_DATA_IN   : std_logic_vector(31 downto 0);
  signal PIX_DAT_MUX_PIX_DATA_REQ  : std_logic;
  signal PIX_DAT_MUX_PIX_DATA_ACK  : std_logic;
  signal PIX_DAT_MUX_PIX_DATA_SYNC : std_logic;
  signal PIX_DAT_MUX_SEQ_DATA_IN   : std_logic_vector(31 downto 0);
  signal PIX_DAT_MUX_SEQ_DATA_REQ  : std_logic;
  signal PIX_DAT_MUX_SEQ_DATA_SYNC : std_logic;
  signal PIX_DAT_MUX_LOC_DATA_REQ  : std_logic;
  signal PIX_DAT_MUX_LOC_DATA_ACK  : std_logic;
  signal PIX_DAT_MUX_LOC_DATA_SYNC : std_logic;
  signal PIX_DAT_MUX_DATA_OUT      : std_logic_vector(31 downto 0);
  signal PIX_DAT_MUX_DATA_WR       : std_logic;
  signal PIX_DAT_MUX_DATA_SYNC     : std_logic;
  signal PIX_DAT_MUX_DATA_BUSY     : std_logic;

  signal SLINK_DATA_IN   : std_logic_vector (31 downto 0);
  signal SLINK_DATA_READ : std_logic;
  signal SLINK_DATA_WRT  : std_logic;
  signal SLINK_LDOWN_N   : std_logic;
  signal SLINK_LFF_N     : std_logic;
  signal SLINK_LRL       : std_logic_vector (3 downto 0);
  signal SLINK_SYNC_IN   : std_logic;
  signal SLINK_DATA_BUSY : std_logic;
  signal SLINK_DATA_OUT  : std_logic_vector (31 downto 0);
  signal SLINK_DATA_RDY  : std_logic;
  signal SLINK_RESET_OUT : std_logic;
  signal SLINK_UCLK      : std_logic;
  signal SLINK_UCTRL_N   : std_logic;
  signal SLINK_UD        : std_logic_vector (31 downto 0);
  signal SLINK_UTEST_N   : std_logic;
  signal SLINK_URESET_N  : std_logic;
  signal SLINK_UWEN_N    : std_logic;
  signal SLINK_activity  : std_logic;
  signal SLINK_linkUp    : std_logic;
  signal SLINK_xoff      : std_logic;


  signal EX_DAT_LATCH_EXDAT_CS  : std_logic;
  signal EX_DAT_LATCH_DATA_IN   : std_logic;
  signal EX_DAT_LATCH_EXDAT_OUT : std_logic;
  signal EX_DAT_LATCH_EXDAT_IN  : std_logic;

----  signal LED_LATCH_SYSCLK       : std_logic;
--  signal LED_LATCH_LED_CS       : std_logic;
----  signal LED_LATCH_RESET_ACTIVE : std_logic;
--  signal LED_LATCH_LED_SRC_1    : std_logic;
--  signal LED_LATCH_LED_SRC_2    : std_logic;
--  signal LED_LATCH_LED_SRC_3    : std_logic;
--  signal LED_LATCH_DATA_IN      : std_logic_vector(2 downto 0);
--  signal LED_LATCH_LED_EN       : std_logic;

  signal clearStats       : std_logic;
  signal statsRcvdDatWrd  : std_logic_vector(31 downto 0);
  signal statsRcvdCtlWrd  : std_logic_vector(31 downto 0);
  signal statsXferDatWrd  : std_logic_vector(31 downto 0);
  signal statsXferCtlWrd  : std_logic_vector(31 downto 0);
  signal statsXferDatPag  : std_logic_vector(31 downto 0);
  signal statsXferCtlPag  : std_logic_vector(31 downto 0);
  signal statsXferDatCPag : std_logic_vector(31 downto 0);
  signal statsXferCtlCPag : std_logic_vector(31 downto 0);
  signal statsLFFErr      : std_logic_vector(15 downto 0);
  signal statsLDownErr    : std_logic_vector(15 downto 0);
  signal statsUpTimeMin   : std_logic_vector(15 downto 0);
  signal statsUpTimeSec   : std_logic_vector(5 downto 0);
  signal infoPageLength   : std_logic_vector(15 downto 0);
  signal infoMaxWait      : std_logic_vector(15 downto 0);
--  signal serConfigIfcDatOut : std_logic_vector(15 downto 0);
  signal exDatLatchDatOut : std_logic_vector(15 downto 0);
  signal ledLatchDatOut   : std_logic_vector(15 downto 0);
  signal pixCmdDecRegData : std_logic_vector(15 downto 0);
  signal localData        : std_logic_vector(15 downto 0);

  
begin  -- Behavioral

  slinkResetOut_n <= not SLINK_RESET_OUT;

  -----------------------------------------------------------------------------
  -- Component Instances
  -----------------------------------------------------------------------------
  -- Pixel data fifo

  PIXEL_DATA_FIFO_V461_1 : PIXEL_DATA_FIFO_V461
    port map (
      CLK            => sysClk,
      RST            => reset,
      DATA_IN        => PIX_DAT_FIFO_DATA_IN,
      DATA_OUT       => PIX_DAT_FIFO_DATA_OUT,
      SEQ_WRT_N      => PIX_DAT_FIFO_SEQ_WRT_N,
      PIPELINE_REQ_N => PIX_DAT_FIFO_PIPELINE_REQ_N,
      PIPELINE_WRT_N => PIX_DAT_FIFO_PIPELINE_WRT_N,
      RD             => PIX_DAT_FIFO_RD,
      DBL_WD_XFER    => PIX_DAT_FIFO_DBL_WD_XFER,
      PIPELINE_ENBL  => PIX_DAT_FIFO_PIPELINE_ENBL,
      DATA_RDY       => PIX_DAT_FIFO_DATA_RDY,
      SYNC_OUT       => PIX_DAT_FIFO_SYNC_OUT,
      SIM_ENABLE     => PIX_DAT_FIFO_SIM_ENABLE,
      SIM_PIXROWS    => PIX_DAT_FIFO_SIM_PIXROWS,
      SIM_PIXCOLS    => PIX_DAT_FIFO_SIM_PIXCOLS,
      SIM_PIXTIME    => PIX_DAT_FIFO_SIM_PIXTIME,
      SIM_CHANNELS   => PIX_DAT_FIFO_SIM_CHANNELS,
      SIM_DELAY      => PIX_DAT_FIFO_SIM_DELAY,
      SIM_TRIGGER    => PIX_DAT_FIFO_SIM_TRIGGER);

  PIX_DAT_FIFO_SIM_TRIGGER                <= simTrigger;
  PIX_DAT_FIFO_DATA_IN(47 downto 0)       <= pix_data(47 downto 0);
  PIX_DAT_FIFO_PIPELINE_REQ_N(6 downto 0) <= pipe_req_n(6 downto 0);
  PIX_DAT_FIFO_PIPELINE_WRT_N             <= pipe_wrt_n;
  PIX_DAT_FIFO_SEQ_WRT_N                  <= seqWrite_n;
--  PIX_DAT_FIFO_RST                        <= RESET;
  PIX_DAT_FIFO_PIPELINE_ENBL              <= not RESET;
  PIX_DAT_FIFO_DBL_WD_XFER                <= PIX_CMD_DEC_DBL_WRD_XFER;
--  PIX_DAT_FIFO_CLK                        <= SYSCLK;
  PIX_DAT_FIFO_RD                         <= PIX_DAT_MUX_PIX_DATA_ACK;

  PIX_DAT_FIFO_SIM_DELAY(7 downto 0)    <= PIX_CMD_DEC_SIM_DELAY(7 downto 0);
  PIX_DAT_FIFO_SIM_CHANNELS(6 downto 0) <= PIX_CMD_DEC_SIM_CHANNELS(6 downto 0);
  PIX_DAT_FIFO_SIM_PIXTIME(7 downto 0)  <= PIX_CMD_DEC_SIM_PIXTIME(7 downto 0);
  PIX_DAT_FIFO_SIM_PIXCOLS(15 downto 0) <= PIX_CMD_DEC_SIM_PIXCOLS(15 downto 0);
  PIX_DAT_FIFO_SIM_PIXROWS(15 downto 0) <= PIX_CMD_DEC_SIM_PIXROWS(15 downto 0);
  PIX_DAT_FIFO_SIM_ENABLE               <= PIX_CMD_DEC_SIM_ENABLE;


  -----------------------------------------------------------------------------
  -- Pix Cmd Decode

  PixCmdDecodeV461_1 : PixCmdDecodeV461
    port map (
      SYSCLK        => sysClk,
      RESET         => reset,
      CMD_RDY       => PIX_CMD_DEC_CMD_RDY,
      CMD_READ      => PIX_CMD_DEC_CMD_READ,
      CMD_DATA      => PIX_CMD_DEC_CMD_DATA,
      ADDRESS       => PIX_CMD_DEC_ADDRESS,
      REG_DATA      => pixCmdDecRegData,
      DATA_OUT      => PIX_CMD_DEC_DATA_OUT,
      READ_REQ      => PIX_CMD_DEC_READ_REQ,
      READ_ACK      => PIX_CMD_DEC_READ_ACK,
      READ_SYNC     => PIX_CMD_DEC_READ_SYNC,
      READ_WRITE_N  => READWRITE_N,
      SLINK_CMD_STB => slinkIfc_cs,
--      CFG_CMD_STB   => PIX_CMD_DEC_CFG_CMD_STB,
      EXD_CMD_STB   => PIX_CMD_DEC_EXD_CMD_STB,
--      FCH_CMD_STB   => PIX_CMD_DEC_FCH_CMD_STB,
      LED_CMD_STB   => PIX_CMD_DEC_LED_CMD_STB,
      DBL_WRD_XFER  => PIX_CMD_DEC_DBL_WRD_XFER,
      SIM_ENABLE    => PIX_CMD_DEC_SIM_ENABLE,
      SIM_PIXROWS   => PIX_CMD_DEC_SIM_PIXROWS,
      SIM_PIXCOLS   => PIX_CMD_DEC_SIM_PIXCOLS,
      SIM_PIXTIME   => PIX_CMD_DEC_SIM_PIXTIME,
      SIM_CHANNELS  => PIX_CMD_DEC_SIM_CHANNELS,
      SIM_DELAY     => PIX_CMD_DEC_SIM_DELAY);

--  PIX_CMD_DEC_RESET    <= RESET;
  PIX_CMD_DEC_CMD_RDY  <= cmdRdy;
  PIX_CMD_DEC_CMD_READ <= pixSeqSyncIn;
  PIX_CMD_DEC_CMD_DATA <= dataIn;
--  PIX_CMD_DEC_SYSCLK   <= SYSCLK;
  PIX_CMD_DEC_READ_ACK <= PIX_DAT_MUX_LOC_DATA_ACK;

  -----------------------------------------------------------------------------
  -- Pix Data Mux

  PixDataMuxV40_1 : PixDataMuxV40
    port map (
      PIX_DATA_IN   => PIX_DAT_MUX_PIX_DATA_IN,
      PIX_DATA_REQ  => PIX_DAT_MUX_PIX_DATA_REQ,
      PIX_DATA_ACK  => PIX_DAT_MUX_PIX_DATA_ACK,
      PIX_DATA_SYNC => PIX_DAT_MUX_PIX_DATA_SYNC,
      SEQ_DATA_IN   => PIX_DAT_MUX_SEQ_DATA_IN,
      SEQ_DATA_REQ  => PIX_DAT_MUX_SEQ_DATA_REQ,
      SEQ_DATA_SYNC => PIX_DAT_MUX_SEQ_DATA_SYNC,
      LOC_DATA_IN   => localData,
      LOC_DATA_REQ  => PIX_DAT_MUX_LOC_DATA_REQ,
      LOC_DATA_ACK  => PIX_DAT_MUX_LOC_DATA_ACK,
      LOC_DATA_SYNC => PIX_DAT_MUX_LOC_DATA_SYNC,
      DATA_OUT      => PIX_DAT_MUX_DATA_OUT,
      DATA_WR       => PIX_DAT_MUX_DATA_WR,
      DATA_SYNC     => PIX_DAT_MUX_DATA_SYNC,
      DATA_BUSY     => PIX_DAT_MUX_DATA_BUSY);

  PIX_DAT_MUX_SEQ_DATA_SYNC            <= pixSeqSyncIn;
  PIX_DAT_MUX_SEQ_DATA_REQ             <= seqDataReq;
  PIX_DAT_MUX_SEQ_DATA_IN              <= dataIn;
  PIX_DAT_MUX_PIX_DATA_REQ             <= PIX_DAT_FIFO_DATA_RDY;
  PIX_DAT_MUX_PIX_DATA_IN(31 downto 0) <= PIX_DAT_FIFO_DATA_OUT(31 downto 0);
  PIX_DAT_MUX_PIX_DATA_SYNC            <= PIX_DAT_FIFO_SYNC_OUT;
  PIX_DAT_MUX_LOC_DATA_SYNC            <= PIX_CMD_DEC_READ_SYNC;
  PIX_DAT_MUX_LOC_DATA_REQ             <= PIX_CMD_DEC_READ_REQ;
  PIX_DAT_MUX_DATA_BUSY                <= SLINK_DATA_BUSY;

  -----------------------------------------------------------------------------
  -- SLINK
  clearStats <= slinkIfc_cs and not READWRITE_N;
  SLinkIfc_1 : SLinkIfc
    port map (
      SYSCLK           => sysClk,
      RESET_IN         => reset,
      DATA_IN          => SLINK_DATA_IN,
      DATA_READ        => SLINK_DATA_READ,
      DATA_WRT         => SLINK_DATA_WRT,
      DATATYPE         => SLINK_SYNC_IN,
      LDOWN_N          => SLINK_LDOWN_N,
      LFF_N            => SLINK_LFF_N,
      LRL              => SLINK_LRL,
      clearStats       => clearStats,
      statsRcvdDatWrd  => statsRcvdDatWrd,
      statsRcvdCtlWrd  => statsRcvdCtlWrd,
      statsXferDatWrd  => statsXferDatWrd,
      statsXferCtlWrd  => statsXferCtlWrd,
      statsXferDatPag  => statsXferDatPag,
      statsXferCtlPag  => statsXferCtlPag,
      statsXferDatCPag => statsXferDatCPag,
      statsXferCtlCPag => statsXferCtlCPag,
      statsLFFErr      => statsLFFErr,
      statsLDownErr    => statsLDownErr,
      statsUpTimeMin   => statsUpTimeMin,
      statsUpTimeSec   => statsUpTimeSec,
      infoPageLength   => infoPageLength,
      infoMaxWait      => infoMaxWait,
      DATA_BUSY        => SLINK_DATA_BUSY,
      DATA_OUT         => SLINK_DATA_OUT,
      DATA_RDY         => SLINK_DATA_RDY,
      RESET_OUT        => SLINK_RESET_OUT,
      UCLK             => SLINK_UCLK,
      UCTRL_N          => SLINK_UCTRL_N,
      UD               => SLINK_UD,
      UTEST_N          => SLINK_UTEST_N,
      URESET_N         => SLINK_URESET_N,
      UWEN_N           => SLINK_UWEN_N,
      activityLed      => SLINK_activity,
      linkUpLed        => SLINK_linkUp,
      xoffLed          => SLINK_xoff);

  UCLK                       <= SLINK_UCLK;
  ud(31 downto 0)            <= SLINK_UD(31 downto 0);
  SLINK_LRL(3 downto 0)      <= LRL(3 downto 0);
  SLINK_LFF_N                <= LFF_N;
  UTEST_N                    <= SLINK_UTEST_N;
  SLINK_LDOWN_N              <= LDOWN_N;
  UWEN_N                     <= SLINK_UWEN_N;
  UCTRL_N                    <= SLINK_UCTRL_N;
  URESET_N                   <= SLINK_URESET_N;
  SLINK_DATA_READ            <= dataRead;
--  SLINK_RESET_IN             <= RESET;
--  SLINK_SYSCLK               <= SYSCLK;
  SLINK_DATA_WRT             <= PIX_DAT_MUX_DATA_WR;
  SLINK_DATA_IN(31 downto 0) <= PIX_DAT_MUX_DATA_OUT(31 downto 0);
  SLINK_SYNC_IN              <= PIX_DAT_MUX_DATA_SYNC;

  dataRdy <= SLINK_DATA_RDY;
  dataOut <= SLINK_DATA_OUT;

  -----------------------------------------------------------------------------
  -- EX dat latch

  ExDataLatchV40_1 : ExDataLatchV40
    port map (
      SYSCLK    => sysClk,
      EXDAT_CS  => EX_DAT_LATCH_EXDAT_CS,
      READ      => READWRITE_N,
      DATA_IN   => EX_DAT_LATCH_DATA_IN,
      DATA_OUT  => exDatLatchDatOut,
      EXDAT_OUT => EX_DAT_LATCH_EXDAT_OUT,
      EXDAT_IN  => EX_DAT_LATCH_EXDAT_IN);

--  EX_DAT_LATCH_SYSCLK   <= SYSCLK;
  EX_DAT_LATCH_EXDAT_IN <= EXDAT_IN;
  EXDAT_OUT             <= EX_DAT_LATCH_EXDAT_OUT;
  EX_DAT_LATCH_DATA_IN  <= PIX_CMD_DEC_DATA_OUT(0);
  EX_DAT_LATCH_EXDAT_CS <= PIX_CMD_DEC_EXD_CMD_STB;

  -----------------------------------------------------------------------------
  -- Led Control Slink
  LedCtrlSlink_1 : LedCtrlSlink
    port map (
      sysClk         => sysClk,
      reset          => reset,
      sel            => PIX_CMD_DEC_LED_CMD_STB,
      rdWr_n         => READWRITE_N,
      dataIn         => PIX_CMD_DEC_DATA_OUT(2 downto 0),
      dataOut        => ledLatchDatOut,
      activityLedSrc => SLINK_activity,
      linkUpLedSrc   => SLINK_linkUp,
      xoffLedSrc     => SLINK_xoff,
      activityLed    => activityLed,
      linkUpLed      => linkUpLed,
      xoffLed        => xoffLed);



--  LedLatchV40Pix_1 : LedLatchV40Pix
--    port map (
--      SYSCLK    => sysClk,
--      LED_CS    => LED_LATCH_LED_CS,
--      READ      => READWRITE_N,
--      RESET     => reset,
--      LED_SRC_1 => LED_LATCH_LED_SRC_1,
--      LED_SRC_2 => LED_LATCH_LED_SRC_2,
--      LED_SRC_3 => LED_LATCH_LED_SRC_3,
--      DATA_IN   => LED_LATCH_DATA_IN,
--      DATA_OUT  => ledLatchDatOut,
--      LED_EN    => LED_LATCH_LED_EN);

--  led_fib                       <= LED_LATCH_LED_EN;
----  LED_LATCH_RESET_ACTIVE        <= RESET;
----  LED_LATCH_SYSCLK              <= SYSCLK;
--  LED_LATCH_LED_SRC_1           <= PIX_DAT_MUX_DATA_WR;
--  LED_LATCH_LED_SRC_2           <= PIX_DAT_MUX_DATA_BUSY;
--  LED_LATCH_LED_SRC_3           <= PIX_DAT_FIFO_DATA_RDY;
--  LED_LATCH_LED_CS              <= PIX_CMD_DEC_LED_CMD_STB;
--  LED_LATCH_DATA_IN(2 downto 0) <= PIX_CMD_DEC_DATA_OUT(2 downto 0);

  -----------------------------------------------------------------------------
  -- reg mux

  regMux_1 : regMux
    port map (
      address            => PIX_CMD_DEC_ADDRESS,
      statsRcvdDatWrd    => statsRcvdDatWrd,
      statsRcvdCtlWrd    => statsRcvdCtlWrd,
      statsXferDatWrd    => statsXferDatWrd,
      statsXferCtlWrd    => statsXferCtlWrd,
      statsXferDatPag    => statsXferDatPag,
      statsXferCtlPag    => statsXferCtlPag,
      statsXferDatCPag   => statsXferDatCPag,
      statsXferCtlCPag   => statsXferCtlCPag,
      statsLFFErr        => statsLFFErr,
      statsLDownErr      => statsLDownErr,
      statsUpTimeMin     => statsUpTimeMin,
      statsUpTimeSec     => statsUpTimeSec,
      infoPageLength     => infoPageLength,
      infoMaxWait        => infoMaxWait,
      serConfigIfcDatOut => (others => '0'),
      exDatLatchDatOut   => exDatLatchDatOut,
      ledLatchDatOut     => ledLatchDatOut,
      pixCmdDecRegData   => pixCmdDecRegData,
      dataOut            => localData);





end Behavioral;
