------------------------------------------------------------------------
-- Copyright Notice:                                                    
-- (c) Copyright 2004, National Optical Astronomy Observatory, which is 
-- operated for the National Science Foundation by the Association of   
-- Universities for Research in Astronomy under Cooperative Agreement   
-- No. AST-0132798.                                                     
--                                                                      
------------------------------------------------------------------------
-- PROJECT      :   MONSOON
-- BOARD        :   GENERIC
-- DEVICE ID    :   U22 (IR ACQ FPGA)
-- PARENT MODULE:   SEQUENCER TOP LEVEL (SEQ_FPGA)  
-- MODULE       :   IMMEDIATE LOOP COUNT GENERIC REGISTERS
-- VERSION      :   1.0 
------------------------------------------------------------------------
-- FILE NAME    :   Loop_Registers.VHD
-- AUTHOR       :   KAVIRAJ CHOPRA
-- DATE         :   03/11/2003
-- COMPANY      :   NOAO
-- PLATFORM     :   Xilinx ISE 4.2
------------------------------------------------------------------------
-- DESCRIPTION  :   
-- The module is an array of 12 bit wide 16 registers for immediate looping 
-- instructions.
------------------------------------------------------------------------
-- IMPLEMENTATION NOTES :

------------------------------------------------------------------------
-- REVISION HISTORY : 
-- DATE   AUTHOR  VERSION  MODIFICATIONS
--
------------------------------------------------------------------------
-- PORT DEFINITIONS :
-- LoopRegDataIn : 12 bit Input Data
-- LoopRegWrite : Write Enable Active High 
-- SysClk : 40 MHz System Clock
-- LoopRegDataOut : Readback Data Output
-- LoopReg0..LoopReg15 :12 bit 16 register outputs to the Dec_Exec_Unit
------------------------------------------------------------------------

library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity Loop_Registers is
    Port ( syscLk         : in  std_logic;
           reset          : in  std_logic;
         LoopRegWrite   : in    std_logic;
         LoopRegAddr    : in    std_logic_vector(3 downto 0);
         LoopRegDataIn  : in    std_logic_vector(15 downto 0);
         LoopRegDataOut : out   std_logic_vector(15 downto 0);

           LoopReg0  : out  std_logic_vector(15 downto 0);
           LoopReg1  : out  std_logic_vector(15 downto 0);
           LoopReg2  : out  std_logic_vector(15 downto 0);
           LoopReg3  : out  std_logic_vector(15 downto 0);
           LoopReg4  : out  std_logic_vector(15 downto 0);
           LoopReg5  : out  std_logic_vector(15 downto 0);
           LoopReg6  : out  std_logic_vector(15 downto 0);
           LoopReg7  : out  std_logic_vector(15 downto 0);
           LoopReg8  : out  std_logic_vector(15 downto 0);
           LoopReg9  : out  std_logic_vector(15 downto 0);
           LoopReg10 : out  std_logic_vector(15 downto 0);
           LoopReg11 : out  std_logic_vector(15 downto 0);
           LoopReg12 : out  std_logic_vector(15 downto 0);
           LoopReg13 : out  std_logic_vector(15 downto 0);
           LoopReg14 : out  std_logic_vector(15 downto 0);
           LoopReg15 : out  std_logic_vector(15 downto 0)
    );
end Loop_Registers;

architecture Behavioral of Loop_Registers is

    type array_16x16 is array(15 downto 0) of std_logic_vector(15 downto 0);
    signal loop_reg: array_16x16;

  begin

--	process (LoopRegAddr, LoopReg0,  LoopReg1,  LoopReg2,  LoopReg3, LoopReg4,
--               LoopReg5,  LoopReg6,  LoopReg7,  LoopReg8,  LoopReg9, LoopReg10, 
--               LoopReg11, LoopReg12, LoopReg13, LoopReg14, LoopReg15)
--	begin
--		case LoopRegAddr is
--		   when "0000" => LoopRegDataOut <= LoopReg0;
--           when "0001" => LoopRegDataOut <= LoopReg1;
--		   when "0010" => LoopRegDataOut <= LoopReg2;
--		   when "0011" => LoopRegDataOut <= LoopReg3;
--		   when "0100" => LoopRegDataOut <= LoopReg4;
--		   when "0101" => LoopRegDataOut <= LoopReg5;
--		   when "0110" => LoopRegDataOut <= LoopReg6;
--		   when "0111" => LoopRegDataOut <= LoopReg7;
--		   when "1000" => LoopRegDataOut <= LoopReg8;
--           when "1001" => LoopRegDataOut <= LoopReg9;
--		   when "1010" => LoopRegDataOut <= LoopReg10;
--		   when "1011" => LoopRegDataOut <= LoopReg11;
--		   when "1100" => LoopRegDataOut <= LoopReg12;
--		   when "1101" => LoopRegDataOut <= LoopReg13;
--		   when "1110" => LoopRegDataOut <= LoopReg14;
--		   when "1111" => LoopRegDataOut <= LoopReg15;
--		   when others => NULL;
--		end case;
--	end process;

LoopRegDataOut <= loop_reg(0)  when (LoopRegAddr="0000") else
                  loop_reg(1)  when (LoopRegAddr="0001") else
                  loop_reg(2)  when (LoopRegAddr="0010") else
                  loop_reg(3)  when (LoopRegAddr="0011") else
                  loop_reg(4)  when (LoopRegAddr="0100") else
                  loop_reg(5)  when (LoopRegAddr="0101") else
                  loop_reg(6)  when (LoopRegAddr="0110") else
                  loop_reg(7)  when (LoopRegAddr="0111") else
                  loop_reg(8)  when (LoopRegAddr="1000") else
                  loop_reg(9)  when (LoopRegAddr="1001") else
                  loop_reg(10) when (LoopRegAddr="1010") else
                  loop_reg(11) when (LoopRegAddr="1011") else
                  loop_reg(12) when (LoopRegAddr="1100") else
                  loop_reg(13) when (LoopRegAddr="1101") else
                  loop_reg(14) when (LoopRegAddr="1110") else
                  loop_reg(15);

--	process (SysClk)
--	begin
--    	if rising_edge (SYSCLK) then
--            if LoopRegWrite = '1' then   --RESET active High
--                case LoopRegAddr is
--        		   when "0000" =>  LoopReg0 <= LoopRegDataIn;
--                   when "0001" =>  LoopReg1 <= LoopRegDataIn; 
--        		   when "0010" =>  LoopReg2 <= LoopRegDataIn; 
--        		   when "0011" =>  LoopReg3 <= LoopRegDataIn;
--        		   when "0100" =>  LoopReg4 <= LoopRegDataIn;
--        		   when "0101" =>  LoopReg5 <= LoopRegDataIn;
--        		   when "0110" =>  LoopReg6 <= LoopRegDataIn;
--        		   when "0111" =>  LoopReg7 <= LoopRegDataIn;
--        		   when "1000" =>  LoopReg8 <= LoopRegDataIn;
--                   when "1001" =>  LoopReg9 <= LoopRegDataIn;
--        		   when "1010" =>  LoopReg10 <= LoopRegDataIn;
--        		   when "1011" =>  LoopReg11 <= LoopRegDataIn;
--        		   when "1100" =>  LoopReg12 <= LoopRegDataIn;
--        		   when "1101" =>  LoopReg13 <= LoopRegDataIn;
--        		   when "1110" =>  LoopReg14 <= LoopRegDataIn;
--        		   when "1111" =>  LoopReg15 <= LoopRegDataIn;
--        		   when others => NULL;
--        		end case;
--            end if;
--        end if;
--	end process;

loop_reg_proc: process(sysclk)
  begin
    if rising_edge(sysclk) then
        if (reset='1') then
            loop_reg(0)  <= X"0000";
            loop_reg(1)  <= X"0000";
            loop_reg(2)  <= X"0000";
            loop_reg(3)  <= X"0000";
            loop_reg(4)  <= X"0000";
            loop_reg(5)  <= X"0000";
            loop_reg(6)  <= X"0000";
            loop_reg(7)  <= X"0000";
            loop_reg(8)  <= X"0000";
            loop_reg(9)  <= X"0000";
            loop_reg(10) <= X"0000";
            loop_reg(11) <= X"0000";
            loop_reg(12) <= X"0000";
            loop_reg(13) <= X"0000";
            loop_reg(14) <= X"0000";
            loop_reg(15) <= X"0000";
        elsif (LoopRegWrite='1') then
        case LoopRegAddr is
                when "0000" =>  loop_reg(0)  <= LoopRegDataIn;
                when "0001" =>  loop_reg(1)  <= LoopRegDataIn; 
                when "0010" =>  loop_reg(2)  <= LoopRegDataIn; 
                when "0011" =>  loop_reg(3)  <= LoopRegDataIn;
                when "0100" =>  loop_reg(4)  <= LoopRegDataIn;
                when "0101" =>  loop_reg(5)  <= LoopRegDataIn;
                when "0110" =>  loop_reg(6)  <= LoopRegDataIn;
                when "0111" =>  loop_reg(7)  <= LoopRegDataIn;
                when "1000" =>  loop_reg(8)  <= LoopRegDataIn;
                when "1001" =>  loop_reg(9)  <= LoopRegDataIn;
                when "1010" =>  loop_reg(10) <= LoopRegDataIn;
                when "1011" =>  loop_reg(11) <= LoopRegDataIn;
                when "1100" =>  loop_reg(12) <= LoopRegDataIn;
                when "1101" =>  loop_reg(13) <= LoopRegDataIn;
                when "1110" =>  loop_reg(14) <= LoopRegDataIn;
                when "1111" =>  loop_reg(15) <= LoopRegDataIn;
          when others => null;
        end case;
      end if;
    end if;
end process loop_reg_proc;

LoopReg0  <= loop_reg(0);
LoopReg1  <= loop_reg(1);
LoopReg2  <= loop_reg(2);
LoopReg3  <= loop_reg(3);
LoopReg4  <= loop_reg(4);
LoopReg5  <= loop_reg(5);
LoopReg6  <= loop_reg(6);
LoopReg7  <= loop_reg(7);
LoopReg8  <= loop_reg(8);
LoopReg9  <= loop_reg(9);
LoopReg10 <= loop_reg(10);
LoopReg11 <= loop_reg(11);
LoopReg12 <= loop_reg(12);
LoopReg13 <= loop_reg(13);
LoopReg14 <= loop_reg(14);
LoopReg15 <= loop_reg(15);

end Behavioral;
