-------------------------------------------------------------------------------
-- Title      : package Sequencer
-- Project    : 
-------------------------------------------------------------------------------
-- File       : packageSeq.vhd
-- Author     :   <otger@PWOTGER>
-- Company    : 
-- Created    : 2009-12-02
-- Last update: 2010-12-17
-- Platform   : 
-- Standard   : VHDL'87
-------------------------------------------------------------------------------
-- Description: Package for component definitions of the sequencer
-------------------------------------------------------------------------------
-- Copyright (c) 2009 
-------------------------------------------------------------------------------
-- Revisions  :
-- Date        Version  Author  Description
-- 2009-12-02  1.0      otger   Created
-------------------------------------------------------------------------------
library ieee;
use ieee.std_logic_1164.all;
use ieee.std_logic_arith.all;
use ieee.std_logic_unsigned.all;


package packageSeq is

  component switchesSelec
    port (
      sysClk        : in  std_logic;
      reset         : in  std_logic;
      writeReg      : in  std_logic;
      dataIn        : in  std_logic_vector(2 downto 0);
      dataOut       : out std_logic_vector(4 downto 0);
      clkSwitchSel  : out std_logic;
      syncSwitchSel : out std_logic;
      isMaster      : in  std_logic);
  end component;

  component ClockEnableRegister
    port (
      CLK          : in  std_logic;
      RST          : in  std_logic;
      WRT          : in  std_logic;
      CLK_EN_DATA  : in  std_logic_vector(15 downto 0);
      CLK_DATA_OUT : out std_logic_vector(15 downto 0);
      bp_clk       : out std_logic_vector(8 downto 2));
  end component;

  component LedCtrlSeq
    port (
      sysClk      : in  std_logic;
      reset       : in  std_logic;
      wrt         : in  std_logic;
      dataIn      : in  std_logic_vector(1 downto 0);
      dataOut     : out std_logic_vector(1 downto 0);
      isMasterSrc : in  std_logic;
      seqRunSrc   : in  std_logic;
      isMasterLed : out std_logic;
      seqRunLed   : out std_logic);
  end component;

  --component LedLatchV40Seq
  --  port (sysclk       : in    std_logic;
  --        reset_active : in    std_logic;
  --        led_src_1    : in    std_logic;
  --        led_src_2    : in    std_logic;
  --        led_src_3    : in    std_logic;
  --        data_in      : in    std_logic_vector (2 downto 0);
  --        data_out     : inout std_logic_vector (2 downto 0);
  --        led_en       : out   std_logic;
  --        wrt          : in    std_logic);
  --end component;

  component seq_mpu
    port (
      sysclk         : in  std_logic;
      reset          : in  std_logic;
      addr_in        : in  std_logic_vector (15 downto 0);
      data_all_in    : in  std_logic_vector (31 downto 0);
      data_ctl_reg   : in  std_logic_vector (15 downto 0);
      se             : in  std_logic;
      seq_bus_ack    : in  std_logic;
      sync_in        : in  std_logic;
      wr_cmd_reg     : in  std_logic;
      wr_int_reg     : in  std_logic;
      wr_loop_regs   : in  std_logic;
      wr_pat         : in  std_logic;
      wr_prog        : in  std_logic;
      data_cmd_reg   : out std_logic_vector (15 downto 0);
      data_int_reg   : out std_logic_vector (31 downto 0);
      data_loop_regs : out std_logic_vector (15 downto 0);
      data_pat       : out std_logic_vector (15 downto 0);
      data_prog      : out std_logic_vector (15 downto 0);
      int_cntr       : out std_logic_vector (31 downto 0);
--      mpu_event      : out std_logic_vector (15 downto 0);
      seq_bus_req    : out std_logic;
      seq_ctl        : out std_logic_vector (31 downto 18);
      seq_pat        : out std_logic_vector (31 downto 0);
      sta_reg        : out std_logic_vector (15 downto 0);
      sync_out       : out std_logic);
  end component;

  component Pan_Command_Decode
    port (CLK           : in  std_logic;
          reset         : in  std_logic;
          DATA_IN_VALID : in  std_logic;
          SEQ_BUS_ACK   : in  std_logic;
          async_pending : out std_logic;
          DATA_IN       : in  std_logic_vector (31 downto 0);
          DATA_IN_RD    : out std_logic;
          MODE          : out std_logic_vector (1 downto 0);
          DEVADDR       : out std_logic_vector (4 downto 0);
          ADDRDATA      : out std_logic_vector (31 downto 0);
          BOARD_SELECT  : out std_logic_vector (7 downto 0);
          LOCSEL        : out std_logic;
          SEQ_BUS_REQ   : out std_logic;
          pixfifo_wrt   : out std_logic;
          START_EXP     : out std_logic;
          exp2cntr : out std_logic;
          echo_req      : out std_logic;
          WRT           : out std_logic;
          rd            : out std_logic;
          WRT_PROG      : out std_logic;
          seqWrite_n    : out std_logic;
--          sync_flag     : out   std_logic;
--          HARD_RST      : out   std_logic;
--          SOFT_RST      : out   std_logic;
          echo_data     : out std_logic_vector (31 downto 0);
          LOCDATA       : out std_logic_vector (31 downto 0);
          LOCADDR       : out std_logic_vector (15 downto 0));
  end component;

  component PATTERN_GENERATOR
    port (CLK      : in  std_logic;
          RST      : in  std_logic;
          LOAD     : in  std_logic;
          DATA_IN  : in  std_logic_vector (31 downto 0);
          DATA_RDY : out std_logic;
          DATA_OUT : out std_logic_vector (31 downto 0);
          strt_exp : in  std_logic;
          enable   : in  std_logic);
  end component;

  component Personality_ModuleV45
    port (
      SYSCLK       : in  std_logic;
      reset        : in  std_logic;
      WRITE        : in  std_logic;
      BOARD_SEL    : in  std_logic;
      LED_REG_SEL  : out std_logic;
      exp2cntr    : in  std_logic;
      crateSyncIn  : in std_logic;
      crateSyncOut : in std_logic;
      LED_DATA     : in  std_logic_vector(1 downto 0);
      TEMP_DATA_IN : in  std_logic_vector(9 downto 0);
      SN_DATA      : in  std_logic_vector(31 downto 0);
      ADDRESS      : in  std_logic_vector(15 downto 0);
      STATUS_REG   : in  std_logic_vector(15 downto 0);
      CLOCKEN_REG  : in  std_logic_vector(15 downto 0);
      SYNCDEL_REG  : in  std_logic_vector(7 downto 0);
      clkDel_reg   : in  std_logic_vector(7 downto 0);
      TST_CTR_REG  : in  std_logic_vector(31 downto 0);
      SEQ_CMD_REG  : in  std_logic_vector(15 downto 0);
      SEQ_INT_REG  : in  std_logic_vector(31 downto 0);
      SEQ_INT_CTR  : in  std_logic_vector(31 downto 0);
      SEQ_LPP_REG  : in  std_logic_vector(15 downto 0);
      SEQ_PAT_MEM  : in  std_logic_vector(15 downto 0);
      SEQ_PGM_MEM  : in  std_logic_vector(15 downto 0);
      ECHO_DATA_IN : in  std_logic_vector(31 downto 0);
      DATA_IN      : in  std_logic_vector(15 downto 0);
      DATA_OUT     : out std_logic_vector(31 downto 0);
      CONTROL_OUT  : out std_logic_vector(15 downto 0);
      CLOCKEN_SEL  : out std_logic;
      SYNCDEL_SEL  : out std_logic;
      clkDel_sel   : out std_logic;
      program_n    : out std_logic;
      SEQ_CMD_SEL  : out std_logic;
      SEQ_INT_SEL  : out std_logic;
      SEQ_LPP_SEL  : out std_logic;
      SEQ_PAT_SEL  : out std_logic;
      TST_CTR_REQ  : in  std_logic;
      TST_CTR_WRT  : out std_logic;
      TST_CTR_ENB  : out std_logic;
      switches_sel : out std_logic;
      switches_reg : in  std_logic_vector(4 downto 0);
      pixSeqSyncOut: out std_logic;
      READ         : in  std_logic;
      READ_STROBE  : in  std_logic;
      ECHO_REQ     : in  std_logic;
      seqDataReq   : out std_logic;
      cmdRdy       : out std_logic);
  end component;

  component delayChipCtrl
    port (
      sysclk      : in  std_logic;
      reset       : in  std_logic;
      write       : in  std_logic;
      delayDatIn  : in  std_logic_vector(7 downto 0);
      delayDatOut : out std_logic_vector(7 downto 0);
      delChipClk  : out std_logic;
      delChipD    : out std_logic;
      delChipE    : out std_logic);
  end component;

  component delayChips
    port (
      sysClk           : in  std_logic;
      reset            : in  std_logic;
      syncWrite        : in  std_logic;
      clkWrite         : in  std_logic;
      dataIn           : in  std_logic_vector(7 downto 0);
      delayChipClk     : out std_logic;
      delayChipData    : out std_logic;
      syncDelayChipEn  : out std_logic;
      clkDelayChipEn   : out std_logic;
      syncDelayCurrVal : out std_logic_vector(7 downto 0);
      clkDelayCurrVal  : out std_logic_vector(7 downto 0));
  end component;

  component Sequencer_Bus_Mux
    port (CLK               : in  std_logic;
          RST               : in  std_logic;
          SEQ_BUS_REQ       : in  std_logic;
          DHE_BUS_REQ       : in  std_logic;
          SEQ_ADDRDATA_IN   : in  std_logic_vector (31 downto 0);
          SEQ_DEV_ADDR_IN   : in  std_logic_vector (4 downto 0);
          SEQ_MODE_IN       : in  std_logic_vector (1 downto 0);
          SEQ_BOARD_SEL_IN  : in  std_logic_vector (6 downto 0);
          DHE_ADDRDATA_IN   : in  std_logic_vector (31 downto 0);
          DHE_DEV_ADDR_IN   : in  std_logic_vector (4 downto 0);
          DHE_MODE_IN       : in  std_logic_vector (1 downto 0);
          DHE_BOARD_SEL_IN  : in  std_logic_vector (7 downto 0);
          SEQ_BUS_ACK       : out std_logic;
          DHE_BUS_ACK       : out std_logic;
          BUS_ADDRDATA_OUT  : out std_logic_vector (31 downto 0);
          BUS_DEV_ADDR_OUT  : out std_logic_vector (4 downto 0);
          BUS_MODE_OUT      : out std_logic_vector (1 downto 0);
          BUS_BOARD_SEL_OUT : out std_logic_vector (8 downto 2));
  end component;

  component serno_interface
    port (
      clock     : in    std_logic;      -- 40MHz system clock
      reset     : in    std_logic;      -- active HIGH reset
      sn_data   : out   std_logic_vector (31 downto 0);
--      sn_crc_ok : out   std_logic;
      sn_io     : inout std_logic
      );
  end component;

  component TempSensor
    port (sysclk    : in  std_logic;
          reset     : in  std_logic;
          temp_dout : in  std_logic;
          temp_din  : out std_logic;
          temp_sclk : out std_logic;
          temp_cs   : out std_logic;
          temp_data : out std_logic_vector (9 downto 0));
  end component;
  

end packageSeq;
