-------------------------------------------------------------------------------
-- Title      : Rising Edge Counter
-- Project    : 
-------------------------------------------------------------------------------
-- File       : risingEdgeCount.vhd
-- Author     :   <otger@OTGER-PC>
-- Company    : 
-- Created    : 2010-12-15
-- Last update: 2010-12-15
-- Platform   : 
-- Standard   : VHDL'87
-------------------------------------------------------------------------------
-- Description: Simple rising edge counter of an input signal
-------------------------------------------------------------------------------
-- Copyright (c) 2010 
-------------------------------------------------------------------------------
-- Revisions  :
-- Date        Version  Author  Description
-- 2010-12-15  1.0      otger   Created
-------------------------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.all;
use IEEE.STD_LOGIC_ARITH.all;
use IEEE.STD_LOGIC_UNSIGNED.all;


entity risingEdgeCount is
  
  generic (
    outWidth : integer range 0 to 32 := 16);

  port (
    sysClk   : in  std_logic;
    reset    : in  std_logic;
    signalIn : in  std_logic;
    count    : out unsigned(outWidth - 1 downto 0));

end risingEdgeCount;

architecture Behavioral of risingEdgeCount is

  signal signalReg  : std_logic;        -- first register for signal in
  signal signalReg2 : std_logic;        -- second register of signal
begin  -- Behavioral

  counterProc : process (sysClk, reset)
    variable tmpCount : unsigned(outWidth - 1 downto 0);
  begin  -- process startExpregProc
    if reset = '1' then                 -- asynchronous reset (active high)
      signalReg2 <= '1';                -- initialize to '1' to avoid false
                                        -- rising edge
      signalReg  <= '1';
      tmpCount   := (others => '0');
    elsif sysClk'event and sysClk = '1' then  -- rising clock edge
      signalReg  <= signalIn;
      signalReg2 <= signalReg;
      if signalReg2 = '0' and signalReg = '1' then
        tmpCount := tmpCount + 1;
      end if;
      count <= tmpCount;
    end if;
  end process counterProc;

end Behavioral;
