library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;

use work.packageSeq.all;

-- synopsys translate_off
library UNISIM;
use UNISIM.Vcomponents.all;
-- synopsys translate_on

entity topSeqFpga is
  port (
    reset          : in    std_logic;
    SYNC_IN        : in    std_logic;
    SYSCLK         : in    std_logic;
    TEMP_DOUT      : in    std_logic;
    BRD_SLCT_N     : out   std_logic_vector (8 downto 2);
    bp_clk         : out   std_logic_vector(8 downto 2);
    DEV_ADDR       : out   std_logic_vector (4 downto 0);
    seqWrite_n     : out   std_logic;
    simTrigger     : out   std_logic;
    PROGRAM_N      : out   std_logic;
    RA_LINK_N      : out   std_logic;
    SEQ_DATA       : out   std_logic_vector (31 downto 0);
    SEQ_MODE       : out   std_logic_vector (1 downto 0);
    START_EXP      : out   std_logic;
    SYNC_OUT       : out   std_logic;
    TEMP_DIN       : out   std_logic;
    TEMP_SCLK      : out   std_logic;
    TEMP_CS        : out   std_logic;
    DQ             : inout std_logic;

    -- leds
    LED_SEQRUNNING        : out   std_logic;
    led_isMaster   : out   std_logic;

    clkSwitchSel   : out std_logic;
    syncSwitchSel  : out std_logic;

    -- Delay chips Interfaces
    delChipClk : out std_logic;
    delChipD   : out std_logic;
    syncDelayChipEn   : out std_logic;
    clkDelayChipEn : out std_logic;

    -- Fpga interface
    dataRdy : in std_logic;
    dataIn : in std_logic_vector(31 downto 0);
    dataRead : out std_logic;
    dataOut : out std_logic_vector(31 downto 0);
    cmdRdy : out std_logic;
    seqDataReq : out std_logic;
    pixSeqSyncOut : out std_logic

    

    );

end topSeqFpga;

architecture BEHAVIORAL of topSeqFpga is
--  signal asyncCmdPending             : std_logic;
  signal BRDSEL                 : std_logic_vector (7 downto 0);
  signal CLKEN_SEL              : std_logic;
  signal CTL_BUSS               : std_logic_vector (15 downto 0);
  signal DHE_SYNC_IN            : std_logic;
  signal ECHO_REQ               : std_logic;
  signal locaddr                : std_logic_vector (15 downto 0);
--  signal LOCAL_CMD              : std_logic;
  signal LOCAL_SEL              : std_logic;
  signal LOCDATA                : std_logic_vector (31 downto 0);
  signal MPU_BUS_ACK            : std_logic;
  signal MPU_BUS_REQ            : std_logic;
  signal PIX_WRT                : std_logic;
  signal READ_DECODE            : std_logic;
--  signal READ_STROBE            : std_logic;
  signal SEQ_ADDRDATA           : std_logic_vector (31 downto 0);
  signal SEQ_BUS_ACK            : std_logic;
  signal SEQ_BUS_REQ            : std_logic;
  signal SEQ_CTL                : std_logic_vector (31 downto 18);
  signal SEQ_DEVADDR            : std_logic_vector (4 downto 0);
  signal SEQ_MODE_SEL           : std_logic_vector (1 downto 0);
  signal SN_DATA                : std_logic_vector (31 downto 0);
--  signal SYNC_OKAY              : std_logic;
  signal TST_CNTR_DATA          : std_logic_vector (31 downto 0);
  signal TST_CNTR_REQ           : std_logic;
  signal TST_CNTR_WRT           : std_logic;
  signal WRITE_DECODE           : std_logic;
--  signal WRITE_STROBE           : std_logic;
  signal WRT_PGM_MEMORY         : std_logic;
  signal WR_LOOPREGS            : std_logic;
  signal SEQ_CMD_SEL                 : std_logic;
  signal SEQ_CMD_REG                : std_logic_vector (15 downto 0);
  signal WR_INT_REG                : std_logic;
  signal seq_int_reg                : std_logic_vector (31 downto 0);
  signal seq_lpp_reg                : std_logic_vector (15 downto 0);
  signal seq_pat_sel                : std_logic;
  signal seq_pat_mem                : std_logic_vector (15 downto 0);
  signal seq_pgm_mem                : std_logic_vector (15 downto 0);
  signal status_reg                : std_logic_vector (15 downto 0);
  signal seq_addrdata_in                : std_logic_vector (31 downto 0);
  signal seq_int_ctr               : std_logic_vector (31 downto 0);
  signal echoData               : std_logic_vector (31 downto 0);
  signal led_reg_sel               : std_logic;
  signal led_data               : std_logic_vector (1 downto 0);
  signal tst_ctr_enable               : std_logic;

  signal tempData               : std_logic_vector (9 downto 0);
--  signal mpuEvents               : std_logic_vector (15 downto 0);
  signal START_EXP_DUMMY        : std_logic;
  signal SYNC_OUT_DUMMY         : std_logic;

  signal clkDataOut : std_logic_vector(15 downto 0);

  signal syncDelayWrite : std_logic;
  signal syncDelayReg : std_logic_vector(7 downto 0);
  signal clkDelayWrite : std_logic;
  signal clkDelayReg : std_logic_vector(7 downto 0);

  signal switchesData : std_logic_vector(4 downto 0);
  signal switchesWrite : std_logic;

  signal isMaster : std_logic;
  signal seqIsRunning : std_logic;


  signal exp2cntr : std_logic;

begin

  
  isMaster <= CTL_BUSS(4);

--  seqIsRunning <= seq_cmd_reg(3);
  seqIsRunning <= MPU_BUS_REQ or SEQ_BUS_REQ or seq_cmd_reg(3);
  
  START_EXP  <= START_EXP_DUMMY;
  SYNC_OUT   <= SYNC_OUT_DUMMY;

--  bp_clk(8 downto 2) <= clk8 & clk7 & clk6 & clk5 & clk4 & clk3 & clk2;
  
  ClockEnableRegister_1: ClockEnableRegister
    port map (
      CLK          => sysClk,
      RST          => reset,
      WRT          => clkEn_sel,
      CLK_EN_DATA  => LOCDATA(15 downto 0),
      CLK_DATA_OUT => clkDataOut(15 downto 0),
      bp_clk       => bp_clk);


  LedControl: LedCtrlSeq
    port map (
      sysClk      => sysClk,
      reset       => reset,
      wrt         => led_reg_sel,
      dataIn      => LOCDATA(1 downto 0),
      dataOut     => led_data(1 downto 0),
      isMasterSrc => isMaster,
      seqRunSrc   => seqIsRunning,
      isMasterLed => led_isMaster,
      seqRunLed   => led_seqRunning);
  
  --LEDCONTROL : LedLatchV40Seq
  --  port map (data_in(2 downto 0)  => LOCDATA(2 downto 0),
  --            led_src_1            => dataRdy,
  --            led_src_2            => SEQ_BUS_REQ,
  --            led_src_3            => MPU_BUS_REQ,
  --            reset_active         => asyncCmdPending,
  --            sysclk               => SYSCLK,
  --            wrt                  => led_reg_sel,
  --            led_en               => LED_SEQ,
  --            data_out(2 downto 0) => led_data(2 downto 0));

  seq_mpu_1: seq_mpu
    port map (
      sysclk         => sysclk,
      reset          => reset,
      addr_in        => locaddr(15 downto 0),
      data_all_in    => LOCDATA(31 downto 0),
      data_ctl_reg   => CTL_BUSS(15 downto 0),
      se             => START_EXP_DUMMY,
      seq_bus_ack    => MPU_BUS_ACK,
      sync_in        => DHE_SYNC_IN,
      wr_cmd_reg     => SEQ_CMD_SEL,
      wr_int_reg     => WR_INT_REG,
      wr_loop_regs   => WR_LOOPREGS,
      wr_pat         => seq_pat_sel,
      wr_prog        => WRT_PGM_MEMORY,
      data_cmd_reg   => SEQ_CMD_REG(15 downto 0),
      data_int_reg   => seq_int_reg(31 downto 0),
      data_loop_regs => seq_lpp_reg(15 downto 0),
      data_pat       => seq_pat_mem(15 downto 0),
      data_prog      => seq_pgm_mem(15 downto 0),
      int_cntr       => seq_int_ctr(31 downto 0),
--      mpu_event      => mpuEvents(15 downto 0),
      seq_bus_req    => MPU_BUS_REQ,
      seq_ctl(31 downto 18) => SEQ_CTL(31 downto 18),
      seq_pat        => seq_addrdata_in(31 downto 0),
      sta_reg        => status_reg(15 downto 0),
      sync_out       => SYNC_OUT_DUMMY);

  PANCOMMANDDEC : Pan_Command_Decode
    port map (--async_pending            => asyncCmdPending,
              CLK                      => SYSCLK,
              DATA_IN(31 downto 0)     => dataIn,
              DATA_IN_VALID            => dataRdy,
              reset                    => RESET,
              SEQ_BUS_ACK              => SEQ_BUS_ACK,
              echo_data(31 downto 0)   => echoData(31 downto 0),
              echo_req                 => ECHO_REQ,
              LOCADDR(15 downto 0)     => locaddr(15 downto 0),
              LOCDATA(31 downto 0)     => LOCDATA(31 downto 0),
              LOCSEL                   => LOCAL_SEL,
              pixfifo_wrt              => PIX_WRT,
              rd                       => READ_DECODE,
              SEQ_BUS_REQ              => SEQ_BUS_REQ,
              START_EXP                => START_EXP_DUMMY,
              exp2cntr => exp2cntr,
              seqWrite_n               => seqWrite_n,
--              sync_flag                => SYNC_OKAY,
              WRT                      => WRITE_DECODE,
              WRT_PROG                 => WRT_PGM_MEMORY,
              ADDRDATA(31 downto 0)    => SEQ_ADDRDATA(31 downto 0),
              BOARD_SELECT(7 downto 0) => BRDSEL(7 downto 0),
              DATA_IN_RD               => dataRead,
              DEVADDR(4 downto 0)      => SEQ_DEVADDR(4 downto 0),
              MODE(1 downto 0)         => SEQ_MODE_SEL(1 downto 0));

  
  patterngenerator : PATTERN_GENERATOR
    port map (CLK                   => SYSCLK,
              DATA_IN(31 downto 0)  => LOCDATA(31 downto 0),
              enable                => tst_ctr_enable,
              LOAD                  => TST_CNTR_WRT,
              RST                   => RESET,
              strt_exp              => START_EXP_DUMMY,
              DATA_OUT(31 downto 0) => TST_CNTR_DATA(31 downto 0),
              DATA_RDY              => TST_CNTR_REQ);

  PersonalityModule : Personality_ModuleV45
    port map (ADDRESS(15 downto 0)      => locaddr(15 downto 0),
              RESET                     => RESET,
              BOARD_SEL                 => LOCAL_SEL,
              crateSyncIn => SYNC_IN,
              crateSyncOut => SYNC_OUT_DUMMY,
              CLOCKEN_REG(15 downto 0)  => clkDataOut(15 downto 0),
              DATA_IN(15 downto 0)      => LOCDATA(15 downto 0),
              ECHO_DATA_IN(31 downto 0) => echoData(31 downto 0),
              ECHO_REQ                  => ECHO_REQ,
              LED_DATA(1 downto 0)      => led_data(1 downto 0),
--              MPU_EVENTS(15 downto 0)   => mpuEvents(15 downto 0),
              READ                      => READ_DECODE,
              READ_STROBE               => PIX_WRT,
              SEQ_CMD_REG(15 downto 0)  => SEQ_CMD_REG(15 downto 0),
              SEQ_INT_CTR(31 downto 0)  => seq_int_ctr(31 downto 0),
              SEQ_INT_REG(31 downto 0)  => seq_int_reg(31 downto 0),
              SEQ_LPP_REG(15 downto 0)  => seq_lpp_reg(15 downto 0),
              SEQ_PAT_MEM(15 downto 0)  => seq_pat_mem(15 downto 0),
              SEQ_PGM_MEM(15 downto 0)  => seq_pgm_mem(15 downto 0),
              SN_DATA(31 downto 0)      => SN_DATA(31 downto 0),
              STATUS_REG(15 downto 0)   => status_reg(15 downto 0),
              SYSCLK                    => SYSCLK,
              TEMP_DATA_IN(9 downto 0)  => tempData(9 downto 0),
              TST_CTR_REG(31 downto 0)  => TST_CNTR_DATA(31 downto 0),
              TST_CTR_REQ               => TST_CNTR_REQ,
              WRITE                     => WRITE_DECODE,
              CLOCKEN_SEL               => CLKEN_SEL,
              CONTROL_OUT(15 downto 0)  => CTL_BUSS(15 downto 0),
              DATA_OUT(31 downto 0)     => dataOut,
              SYNCDEL_SEL               => syncDelayWrite,
              SYNCDEL_REG               => syncDelayReg,
              clkDel_sel => clkDelayWrite,
              clkDel_reg => clkDelayReg,
              switches_reg => switchesData,
              switches_sel => switchesWrite,
              program_n                 => PROGRAM_N,
              exp2cntr => exp2cntr,
              LED_REG_SEL               => led_reg_sel,
              SEQ_CMD_SEL               => SEQ_CMD_SEL,
              SEQ_INT_SEL               => WR_INT_REG,
              SEQ_LPP_SEL               => WR_LOOPREGS,
              SEQ_PAT_SEL               => seq_pat_sel,
              pixSeqSyncOut             => pixSeqSyncOut,
              TST_CTR_ENB               => tst_ctr_enable,
              TST_CTR_WRT               => TST_CNTR_WRT,
              cmdRdy                    => cmdRdy,
              seqDataReq                => seqDataReq);

  switchesSelec_1: switchesSelec
    port map (
      sysClk        => sysClk,
      reset         => reset,
      writeReg      => switchesWrite,
      dataIn        => LOCDATA(2 downto 0),
      dataOut       => switchesData,
      clkSwitchSel  => clkSwitchSel,
      syncSwitchSel => syncSwitchSel,
      isMaster      => isMaster);

  delayChips_1: delayChips
    port map (
      sysClk           => sysClk,
      reset            => reset,
      syncWrite        => syncDelayWrite,
      clkWrite         => clkDelayWrite,
      dataIn           => LOCDATA(7 downto 0),
      delayChipClk     => delChipClk,
      delayChipData    => delChipD,
      syncDelayChipEn  => syncDelayChipEn,
      clkDelayChipEn   => clkDelayChipEn,
      syncDelayCurrVal => syncDelayReg,
      clkDelayCurrVal  => clkDelayReg);

  SEQBUSMUX : Sequencer_Bus_Mux
    port map (CLK                           => SYSCLK,
              DHE_ADDRDATA_IN(31 downto 0)  => SEQ_ADDRDATA(31 downto 0),
              DHE_BOARD_SEL_IN(7 downto 0)  => BRDSEL(7 downto 0),
              DHE_BUS_REQ                   => SEQ_BUS_REQ,
              DHE_DEV_ADDR_IN(4 downto 0)   => SEQ_DEVADDR(4 downto 0),
              DHE_MODE_IN(1 downto 0)       => SEQ_MODE_SEL(1 downto 0),
              RST                           => RESET,
              SEQ_ADDRDATA_IN(31 downto 0)  => seq_addrdata_in(31 downto 0),
              SEQ_BOARD_SEL_IN(6 downto 0)  => SEQ_CTL(24 downto 18),
              SEQ_BUS_REQ                   => MPU_BUS_REQ,
              SEQ_DEV_ADDR_IN(4 downto 0)   => SEQ_CTL(29 downto 25),
              SEQ_MODE_IN(1 downto 0)       => SEQ_CTL(31 downto 30),
              BUS_ADDRDATA_OUT(31 downto 0) => SEQ_DATA(31 downto 0),
              BUS_BOARD_SEL_OUT(8 downto 2) => BRD_SLCT_N(8 downto 2),
              BUS_DEV_ADDR_OUT(4 downto 0)  => DEV_ADDR(4 downto 0),
              BUS_MODE_OUT(1 downto 0)      => SEQ_MODE(1 downto 0),
              DHE_BUS_ACK                   => SEQ_BUS_ACK,
              SEQ_BUS_ACK                   => MPU_BUS_ACK);

  SERNUMIFC : serno_interface
    port map(
      clock     => sysclk,
      reset     => reset,
      sn_data   => SN_DATA(31 downto 0),
--      sn_crc_ok => open,
      sn_io     => DQ
      );

  TEMPSENSORIFC : TempSensor
    port map (
              sysclk                => SYSCLK,
              reset => reset,
              temp_dout             => TEMP_DOUT,
              temp_data(9 downto 0) => tempData(9 downto 0),
              temp_din              => TEMP_DIN,
              temp_cs               => TEMP_CS,
              temp_sclk             => TEMP_SCLK);

  DHE_SYNC_IN <= SYNC_IN;


  RA_LINK_N <= RESET;

  simTrigger <= START_EXP_DUMMY;

  
end BEHAVIORAL;
