-------------------------------------------------------------------------------
-- Title      : Temperature sensor interface testbench
-- Project    : 
-------------------------------------------------------------------------------
-- File       : TempSensorTb.vhd
-- Author     :   <otger@PWOTGER>
-- Company    : 
-- Created    : 2009-04-01
-- Last update: 2009-04-02
-- Platform   : 
-- Standard   : VHDL'87
-------------------------------------------------------------------------------
-- Description: Simple testbench for the temperature sensor serial interface
-------------------------------------------------------------------------------
-- Copyright (c) 2009 
-------------------------------------------------------------------------------
-- Revisions  :
-- Date        Version  Author  Description
-- 2009-04-01  1.0      otger	Created
-------------------------------------------------------------------------------

library ieee;
use ieee.std_logic_1164.all;

entity TempSensorTb is
  
end TempSensorTb;

architecture behavioral of TempSensorTb is
  component TempSensor
    port (
      SYSCLK    : in  std_logic;
      RESET     : in  std_logic;
      TEMP_DATA : out std_logic_vector(9 downto 0);
      TEMP_DIN  : out std_logic;
      TEMP_DOUT : in  std_logic;
      TEMP_CS   : out std_logic;
      TEMP_SCLK : out std_logic);
  end component;

  signal SYSCLK    : std_logic;
  signal RESET     : std_logic;
  signal TEMP_DATA : std_logic_vector(9 downto 0);
  signal TEMP_DIN  : std_logic;
  signal TEMP_DOUT : std_logic;
  signal TEMP_CS   : std_logic;
  signal TEMP_SCLK : std_logic;

  constant TEMPERATURE : std_logic_vector(9 downto 0) := "10" & x"aa";

  constant TSysclk : time := 25 ns;
  
begin  -- behavioral

  process
  begin  -- process
    RESET <= '1';
    wait for 250 ns;
    RESET <= '0';
    wait;
  end process;

  -- purpose: generate sysClk
  -- type   : combinational
  -- inputs : 
  -- outputs: 
  process
  begin  -- process
    sysClk <= '0';
    wait for TSysclk/2;
    sysClk <= '1';
    wait for TSysclk/2;
  end process;

  process
  begin  -- process
    TEMP_DOUT <= '0';
    wait until TEMP_CS = '0';
    TEMP_DOUT <= '0';                   -- leading zero
    wait until TEMP_SCLK = '1';
    wait until TEMP_SCLK = '0';
    wait for 35 ns;
    TEMP_DOUT <= TEMPERATURE(9);
    wait until TEMP_SCLK = '1';
    wait until TEMP_SCLK = '0';
    wait for 35 ns;
    TEMP_DOUT <= TEMPERATURE(8);
    wait until TEMP_SCLK = '1';
    wait until TEMP_SCLK = '0';
    wait for 35 ns;
    TEMP_DOUT <= TEMPERATURE(7);
    wait until TEMP_SCLK = '1';
    wait until TEMP_SCLK = '0';
    wait for 35 ns;
    TEMP_DOUT <= TEMPERATURE(6);
    wait until TEMP_SCLK = '1';
    wait until TEMP_SCLK = '0';
    wait for 35 ns;
    TEMP_DOUT <= TEMPERATURE(5);
    wait until TEMP_SCLK = '1';
    wait until TEMP_SCLK = '0';
    wait for 35 ns;
    TEMP_DOUT <= TEMPERATURE(4);
    wait until TEMP_SCLK = '1';
    wait until TEMP_SCLK = '0';
    wait for 35 ns;
    TEMP_DOUT <= TEMPERATURE(3);
    wait until TEMP_SCLK = '1';
    wait until TEMP_SCLK = '0';
    wait for 35 ns;
    TEMP_DOUT <= TEMPERATURE(2);
    wait until TEMP_SCLK = '1';
    wait until TEMP_SCLK = '0';
    wait for 35 ns;
    TEMP_DOUT <= TEMPERATURE(1);
    wait until TEMP_SCLK = '1';
    wait until TEMP_SCLK = '0';
    wait for 35 ns;
    TEMP_DOUT <= TEMPERATURE(0);
    wait until TEMP_SCLK = '1';
    wait until TEMP_SCLK = '0';
    wait for 35 ns;
    TEMP_DOUT <= '0';
    wait until TEMP_SCLK = '1';
    wait until TEMP_SCLK = '0';
    wait until TEMP_SCLK = '1';
    wait until TEMP_SCLK = '0';
    wait until TEMP_SCLK = '1';
    wait until TEMP_SCLK = '0';
    wait until TEMP_SCLK = '1';
    wait until TEMP_SCLK = '0';
    wait until TEMP_SCLK = '1';

  end process;
  TempSensor_1: TempSensor
    port map (
      SYSCLK    => SYSCLK,
      RESET     => RESET,
      TEMP_DATA => TEMP_DATA,
      TEMP_DIN  => TEMP_DIN,
      TEMP_DOUT => TEMP_DOUT,
      TEMP_CS   => TEMP_CS,
      TEMP_SCLK => TEMP_SCLK);

end behavioral;
