-- model for the MCB board including 
-- the main FPGA, temp sensor, "one wire" device
-- this file handles the power on reset and provides the clock
-- from a 40MHz oscillator.  None of the MCB clock sync logic
-- is included here.

library ieee;
use ieee.std_logic_1164.all;

entity mcb is
  port (
    pix_data     : in    std_logic_vector(47 downto 0);
    pipe_req_n   : in    std_logic_vector(6 downto 0);
    pipe_wrt_n   : in    std_logic;
    ack_n        : in    std_logic_vector(8 downto 2);
    spr          : inout std_logic_vector(8 downto 0);
    bpclock      : out   std_logic_vector(8 downto 2);
    board_slct_n : out   std_logic_vector(8 downto 2);
    seq_mode     : out   std_logic_vector(1 downto 0);
    dev_addr     : out   std_logic_vector(5 downto 0);
    seq_data     : out   std_logic_vector(31 downto 0);
    start_exp    : out   std_logic);
end mcb;

architecture mcb_arch of mcb is

component mcbFull
  port (
    sysclk       : in    std_logic;
    dq           : inout std_logic;
    led_seq      : out   std_logic;
    temp_sclk    : out   std_logic;
    temp_dout    : in    std_logic;
    temp_din     : out   std_logic;
    ra_link_n    : out   std_logic;
    program_n    : out   std_logic;
    fpga_ctl_6   : out   std_logic;
    tp_11        : out   std_logic;
    tp_12        : out   std_logic;
    tp_13        : out   std_logic;
    tp_14        : out   std_logic;
    tp_19        : out   std_logic;
    tp_20        : out   std_logic;
    tp_21        : out   std_logic;
    tp_22        : in    std_logic;
    board_slct_n : out   std_logic_vector(8 downto 2);
    seq_mode     : out   std_logic_vector(1 downto 0);
    dev_addr     : out   std_logic_vector(5 downto 0);
    seq_data     : out   std_logic_vector(31 downto 0);
    clk2         : out   std_logic;
    clk3         : out   std_logic;
    clk4         : out   std_logic;
    clk5         : out   std_logic;
    clk6         : out   std_logic;
    clk7         : out   std_logic;
    clk8         : out   std_logic;
    sync_in      : in    std_logic;
    sync_out     : out   std_logic;
    start_exp    : out   std_logic;
    pix_data     : in    std_logic_vector(47 downto 0);
    pipe_req_n   : in    std_logic_vector(6 downto 0);
    pipe_wrt_n   : in    std_logic;
    led_fib      : out   std_logic;
    clk1f0       : out   std_logic;
    clk1f1       : out   std_logic;
    clk2f0       : out   std_logic;
    clk2f1       : out   std_logic;
    scl          : out   std_logic;
    sda          : inout std_logic;
    exdat_in     : in    std_logic;
    exdat_out    : out   std_logic;
    uclk         : out   std_logic;
    ud           : out   std_logic_vector(31 downto 0);
    lrl          : in    std_logic_vector(3 downto 0);
    lff_n        : in    std_logic;
    utest_n      : out   std_logic;
    ldown_n      : in    std_logic;
    uwen_n       : out   std_logic;
    uctrl_n      : out   std_logic;
    ureset_n     : out   std_logic;
    ack_n        : in    std_logic_vector(8 downto 2);
    resetInHw_n  : in    std_logic;
    spr          : inout std_logic_vector(8 downto 0);
    delay_din    : out   std_logic;
    temp_cs      : out   std_logic;
    delay_dout   : in    std_logic;
    delay_en     : out   std_logic;
    delay_clk    : out   std_logic);
end component;
--  component mcbFull
--    port(
--      sysclk       : in    std_logic;
--      reset_n      : in    std_logic;
--      pix_data     : in    std_logic_vector(47 downto 0);  -- monsoon backplane bus
--      pipe_req_n   : in    std_logic_vector(6 downto 0);
--      pipe_wrt_n   : in    std_logic;
--      ack_n        : in    std_logic_vector(8 downto 2);
--      spr          : inout std_logic_vector(8 downto 0);
--      clkout       : out   std_logic_vector(8 downto 2);
--      board_slct_n : out   std_logic_vector(8 downto 2);
--      seq_mode     : out   std_logic_vector(1 downto 0);
--      dev_addr     : out   std_logic_vector(5 downto 0);
--      seq_data     : out   std_logic_vector(31 downto 0);
--      start_exp    : out   std_logic;
--      --    sync_in    : in  std_logic;      -- external sync controls
--      --    sync_out   : out std_logic;
--      --        delay_dout : in  std_logic;
--      --        delay_en   : out std_logic;
--      --        delay_clk  : out std_logic;
--      --        delay_din  : out std_logic;
--      --    exdat_in  : in    std_logic;
--      --    exdat_out : out   std_logic;
--      --    clk1f0 : out   std_logic;
--      --    clk1f1 : out   std_logic;
--      --    clk2f0 : out   std_logic;
--      --    clk2f1 : out   std_logic;
--      lrl          : in    std_logic_vector(3 downto 0);   -- slink interface
--      lff_n        : in    std_logic;
--      ldown_n      : in    std_logic;
--      uclk         : out   std_logic;
--      ud           : out   std_logic_vector(31 downto 0);
--      utest_n      : out   std_logic;
--      uwen_n       : out   std_logic;
--      uctrl_n      : out   std_logic;
--      ureset_n     : out   std_logic;
--      dq           : inout std_logic;  -- serial number "one wire" device with EEPROM
--      led_seq      : out   std_logic;   -- front panel LEDs
--      led_fib      : out   std_logic;
--      temp_dout    : in    std_logic;   -- temperature sensor
--      temp_cs      : out   std_logic;
--      temp_sclk    : out   std_logic;
--      temp_din     : out   std_logic;
--      program_n    : out   std_logic);
--  end component;

  component ds2433
    port(data : inout std_logic);
  end component;

  component ad7814
    generic(temp : integer := 25);      -- temp range -55C to 125C
    port(
      sclk : in  std_logic;
      cs_n : in  std_logic;
      din  : in  std_logic;
      dout : out std_logic);
  end component;

  component hola is
    port(
      uclk     : in  std_logic;
      ud       : in  std_logic_vector(31 downto 0);
      utest_n  : in  std_logic;
      uwen_n   : in  std_logic;
      uctrl_n  : in  std_logic;
      ureset_n : in  std_logic;
      lrl      : out std_logic_vector(3 downto 0);
      lff_n    : out std_logic;
      ldown_n  : out std_logic);
  end component;

  signal reset_n          : std_logic;
  signal osc_clock        : std_logic := '0';
  signal osc_clock_period : time      := 25 ns;

  signal lrl                           : std_logic_vector(3 downto 0);
  signal ud                            : std_logic_vector(31 downto 0);
  signal lff_n, ldown_n, uclk, utest_n : std_logic;
  signal uwen_n, uctrl_n, ureset_n     : std_logic;

  signal dq, temp_dout, temp_cs, temp_sclk, temp_din : std_logic;
  signal program_n                                   : std_logic;

begin

  reset_n   <= '0', '1'      after 200 ns;
  osc_clock <= not osc_clock after osc_clock_period/2;

-- instantiate MCB FPGA 
  
  mcbFull_inst : mcbFull
    port map(
      sysclk  => osc_clock,             -- on board oscillator
      resetInHw_n => reset_n,

      sync_in => '0',
      exdat_in => '0',
      delay_dout => '0',
      
      pix_data     => pix_data,         -- monsoon backplane bus
      pipe_req_n   => pipe_req_n,
      pipe_wrt_n   => pipe_wrt_n,
      ack_n        => ack_n,
      spr          => spr,
      tp_22 => reset_n,
      clk2         => bpclock(2),
      clk3         => bpclock(3),
      clk4         => bpclock(4),
      clk5         => bpclock(5),
      clk6         => bpclock(6),
      clk7         => bpclock(7),
      clk8         => bpclock(8),
      board_slct_n => board_slct_n,
      seq_mode     => seq_mode,
      dev_addr     => dev_addr(5 downto 0),
--      dev_addr5 => dev_addr(5),
      seq_data     => seq_data,
      start_exp    => start_exp,

      lrl     => lrl,                   -- inputs from HOLA
      lff_n   => lff_n,
      ldown_n => ldown_n,

      uclk     => uclk,                 -- outputs to HOLA
      ud       => ud,
      utest_n  => utest_n,
      uwen_n   => uwen_n,
      uctrl_n  => uctrl_n,
      ureset_n => ureset_n,

      dq => dq,                         -- Serial number / NVRAM

      temp_dout => temp_dout,           -- temperature sensor
      temp_cs   => temp_cs,
      temp_sclk => temp_sclk,
      temp_din  => temp_din
      );

-- instantiate the HOLA daughterboard
-- this is the module really drives the whole testbench

  hola_inst : hola
    port map(
      lrl      => lrl,
      lff_n    => lff_n,
      ldown_n  => ldown_n,
      uclk     => uclk,
      ud       => ud,
      utest_n  => utest_n,
      uwen_n   => uwen_n,
      uctrl_n  => uctrl_n,
      ureset_n => ureset_n);

-- serial number and NVRAM on the MCB board

  ds2433_inst : ds2433
    port map(data => dq);

-- temp sensor on the MCB board

  ad7814_inst : ad7814
    port map(
      sclk => temp_sclk,
      cs_n => temp_cs,
      din  => temp_din,
      dout => temp_dout
      );

-- watch the PROGRAM_N signal and report that the FPGA is 
-- "rebooting" itself.  (models the external one shot device)

  reboot_monitor : process(PROGRAM_N)
  begin
    if falling_edge(PROGRAM_N) then
      report "MCB is rebooting itself!" severity warning;
    end if;
  end process reboot_monitor;

end mcb_arch;
