-- testbench for a DHE crate with a MCB and some CCD12 boards

library ieee;
use ieee.std_logic_1164.all;

entity testbench is
end testbench;

architecture testbench_arch of testbench is

  component mcb
    port(
      pix_data     : in    std_logic_vector(47 downto 0);
      pipe_req_n   : in    std_logic_vector(6 downto 0);
      pipe_wrt_n   : in    std_logic;
      ack_n        : in    std_logic_vector(8 downto 2);
      spr          : inout std_logic_vector(8 downto 0);
      bpclock      : out   std_logic_vector(8 downto 2);
      board_slct_n : out   std_logic_vector(8 downto 2);
      seq_mode     : out   std_logic_vector(1 downto 0);
      dev_addr     : out   std_logic_vector(5 downto 0);
      seq_data     : out   std_logic_vector(31 downto 0);
      start_exp    : out   std_logic);
  end component;

  component ccd12 is
    port(
      clock        : in  std_logic;
      board_slct_n : in  std_logic;
      seq_mode     : in  std_logic_vector(1 downto 0);
      dev_addr     : in  std_logic_vector(5 downto 0);
      seq_data     : in  std_logic_vector(31 downto 0);
      pix_data     : out std_logic_vector(47 downto 0);
      ack_n        : out std_logic);
  end component;

  signal bpclock      : std_logic_vector(8 downto 2);
  signal board_slct_n : std_logic_vector(8 downto 2);
  signal seq_data     : std_logic_vector(31 downto 0);
  signal dev_addr     : std_logic_vector(5 downto 0);
  signal seq_mode     : std_logic_vector(1 downto 0);
  signal pix_data     : std_logic_vector(47 downto 0);
  signal ack_n        : std_logic_vector(8 downto 2);
  signal spr          : std_logic_vector(8 downto 0);

begin

  mcb_inst : mcb
    port map(
      pix_data     => pix_data,
      pipe_req_n   => "1111111",        -- pipeline xfer modes disabled
      pipe_wrt_n   => '1',              -- (CCD12 model does not support it)
      ack_n        => ack_n,
      spr          => spr,
      bpclock      => bpclock,
      board_slct_n => board_slct_n,
      seq_mode     => seq_mode,
      dev_addr     => dev_addr,
      seq_data     => seq_data);

  ccd12_slot3 : ccd12
    port map(
      clock        => bpclock(3),
      board_slct_n => board_slct_n(3),
      seq_mode     => seq_mode,
      dev_addr     => dev_addr,
      seq_data     => seq_data,
      pix_data     => pix_data,
      ack_n        => ack_n(3));

  ccd12_slot6 : ccd12
    port map(
      clock        => bpclock(6),
      board_slct_n => board_slct_n(6),
      seq_mode     => seq_mode,
      dev_addr     => dev_addr,
      seq_data     => seq_data,
      pix_data     => pix_data,
      ack_n        => ack_n(6));

end testbench_arch;
